"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class BatchSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DATE_CREATED_COLUMN_FIELD_NUMBER: builtins.int
    ATHENASOURCE_FIELD_NUMBER: builtins.int
    MONGOSOURCE_FIELD_NUMBER: builtins.int
    CSVSOURCE_FIELD_NUMBER: builtins.int
    SNOWFLAKESOURCE_FIELD_NUMBER: builtins.int
    PARQUETSOURCE_FIELD_NUMBER: builtins.int
    JDBCSOURCE_FIELD_NUMBER: builtins.int
    VERTICASOURCE_FIELD_NUMBER: builtins.int
    BIGQUERYSOURCE_FIELD_NUMBER: builtins.int
    ELASTICSEARCHSOURCE_FIELD_NUMBER: builtins.int
    CLICKHOUSESOURCE_FIELD_NUMBER: builtins.int
    FEATURESETOFFLINESOURCE_FIELD_NUMBER: builtins.int
    CATALOGSOURCE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Source given name (by the user)"""
    description: builtins.str
    """Source description"""
    date_created_column: builtins.str
    """Date column of the database, used slicing the data already processed by the feature store engine"""
    @property
    def athenaSource(self) -> global___AthenaSource: ...
    @property
    def mongoSource(self) -> global___MongoSource: ...
    @property
    def csvSource(self) -> global___CsvSource: ...
    @property
    def snowflakeSource(self) -> global___SnowflakeSource: ...
    @property
    def parquetSource(self) -> global___ParquetSource: ...
    @property
    def jdbcSource(self) -> global___JdbcSource: ...
    @property
    def verticaSource(self) -> global___VerticaSource: ...
    @property
    def bigquerySource(self) -> global___BigquerySource: ...
    @property
    def elasticsearchSource(self) -> global___ElasticsearchSource: ...
    @property
    def clickhouseSource(self) -> global___ClickhouseSource: ...
    @property
    def featuresetOfflineSource(self) -> global___FeaturesetOfflineSource: ...
    @property
    def catalogSource(self) -> global___CatalogSource: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        date_created_column: builtins.str = ...,
        athenaSource: global___AthenaSource | None = ...,
        mongoSource: global___MongoSource | None = ...,
        csvSource: global___CsvSource | None = ...,
        snowflakeSource: global___SnowflakeSource | None = ...,
        parquetSource: global___ParquetSource | None = ...,
        jdbcSource: global___JdbcSource | None = ...,
        verticaSource: global___VerticaSource | None = ...,
        bigquerySource: global___BigquerySource | None = ...,
        elasticsearchSource: global___ElasticsearchSource | None = ...,
        clickhouseSource: global___ClickhouseSource | None = ...,
        featuresetOfflineSource: global___FeaturesetOfflineSource | None = ...,
        catalogSource: global___CatalogSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["athenaSource", b"athenaSource", "bigquerySource", b"bigquerySource", "catalogSource", b"catalogSource", "clickhouseSource", b"clickhouseSource", "csvSource", b"csvSource", "elasticsearchSource", b"elasticsearchSource", "featuresetOfflineSource", b"featuresetOfflineSource", "jdbcSource", b"jdbcSource", "mongoSource", b"mongoSource", "parquetSource", b"parquetSource", "snowflakeSource", b"snowflakeSource", "type", b"type", "verticaSource", b"verticaSource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["athenaSource", b"athenaSource", "bigquerySource", b"bigquerySource", "catalogSource", b"catalogSource", "clickhouseSource", b"clickhouseSource", "csvSource", b"csvSource", "date_created_column", b"date_created_column", "description", b"description", "elasticsearchSource", b"elasticsearchSource", "featuresetOfflineSource", b"featuresetOfflineSource", "jdbcSource", b"jdbcSource", "mongoSource", b"mongoSource", "name", b"name", "parquetSource", b"parquetSource", "snowflakeSource", b"snowflakeSource", "type", b"type", "verticaSource", b"verticaSource"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["athenaSource", "mongoSource", "csvSource", "snowflakeSource", "parquetSource", "jdbcSource", "verticaSource", "bigquerySource", "elasticsearchSource", "clickhouseSource", "featuresetOfflineSource", "catalogSource"] | None: ...

global___BatchSource = BatchSource

class FileSystemConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AWS_S3_CONFIGURATION_FIELD_NUMBER: builtins.int
    AWS_S3_ANONYMOUS_FIELD_NUMBER: builtins.int
    AWS_S3_ASSUME_ROLE_CONFIGURATION_FIELD_NUMBER: builtins.int
    GCS_UNAUTHENTICATED_FIELD_NUMBER: builtins.int
    GCS_USER_CREDENTIALS_FIELD_NUMBER: builtins.int
    GCS_SERVICE_ACCOUNT_IMPERSONATION_FIELD_NUMBER: builtins.int
    @property
    def aws_s3_configuration(self) -> global___AwsS3FileSystemConfiguration: ...
    @property
    def aws_s3_anonymous(self) -> global___AnonymousS3Configuration: ...
    @property
    def aws_s3_assume_role_configuration(self) -> global___AwsS3AssumeRole: ...
    @property
    def gcs_unauthenticated(self) -> global___GcsUnauthenticated: ...
    @property
    def gcs_user_credentials(self) -> global___GcsUserCredentials: ...
    @property
    def gcs_service_account_impersonation(self) -> global___GcsServiceAccountImpersonation: ...
    def __init__(
        self,
        *,
        aws_s3_configuration: global___AwsS3FileSystemConfiguration | None = ...,
        aws_s3_anonymous: global___AnonymousS3Configuration | None = ...,
        aws_s3_assume_role_configuration: global___AwsS3AssumeRole | None = ...,
        gcs_unauthenticated: global___GcsUnauthenticated | None = ...,
        gcs_user_credentials: global___GcsUserCredentials | None = ...,
        gcs_service_account_impersonation: global___GcsServiceAccountImpersonation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_s3_anonymous", b"aws_s3_anonymous", "aws_s3_assume_role_configuration", b"aws_s3_assume_role_configuration", "aws_s3_configuration", b"aws_s3_configuration", "gcs_service_account_impersonation", b"gcs_service_account_impersonation", "gcs_unauthenticated", b"gcs_unauthenticated", "gcs_user_credentials", b"gcs_user_credentials", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_s3_anonymous", b"aws_s3_anonymous", "aws_s3_assume_role_configuration", b"aws_s3_assume_role_configuration", "aws_s3_configuration", b"aws_s3_configuration", "gcs_service_account_impersonation", b"gcs_service_account_impersonation", "gcs_unauthenticated", b"gcs_unauthenticated", "gcs_user_credentials", b"gcs_user_credentials", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["aws_s3_configuration", "aws_s3_anonymous", "aws_s3_assume_role_configuration", "gcs_unauthenticated", "gcs_user_credentials", "gcs_service_account_impersonation"] | None: ...

global___FileSystemConfiguration = FileSystemConfiguration

class AwsS3AssumeRole(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_ARN_FIELD_NUMBER: builtins.int
    role_arn: builtins.str
    """Role to assume"""
    def __init__(
        self,
        *,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["role_arn", b"role_arn"]) -> None: ...

global___AwsS3AssumeRole = AwsS3AssumeRole

class AwsS3FileSystemConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_SECRET_NAME_FIELD_NUMBER: builtins.int
    SECRET_KEY_SECRET_NAME_FIELD_NUMBER: builtins.int
    SESSION_TOKEN_SECRET_NAME_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    access_key_secret_name: builtins.str
    """AWS s3 access key"""
    secret_key_secret_name: builtins.str
    """AWS s3 secret key"""
    session_token_secret_name: builtins.str
    """AWS s3 session token"""
    bucket: builtins.str
    """AWS s3 bucket"""
    def __init__(
        self,
        *,
        access_key_secret_name: builtins.str = ...,
        secret_key_secret_name: builtins.str = ...,
        session_token_secret_name: builtins.str = ...,
        bucket: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key_secret_name", b"access_key_secret_name", "bucket", b"bucket", "secret_key_secret_name", b"secret_key_secret_name", "session_token_secret_name", b"session_token_secret_name"]) -> None: ...

global___AwsS3FileSystemConfiguration = AwsS3FileSystemConfiguration

class AnonymousS3Configuration(google.protobuf.message.Message):
    """Anonymous S3 access"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AnonymousS3Configuration = AnonymousS3Configuration

class JdbcSource(google.protobuf.message.Message):
    """Jdbc Batch source"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    USERNAME_SECRET_NAME_FIELD_NUMBER: builtins.int
    PASSWORD_SECRET_NAME_FIELD_NUMBER: builtins.int
    DB_TABLE_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    MYSQLSOURCE_FIELD_NUMBER: builtins.int
    POSTGRESQLSOURCE_FIELD_NUMBER: builtins.int
    REDSHIFTSOURCE_FIELD_NUMBER: builtins.int
    ATHENASOURCE_FIELD_NUMBER: builtins.int
    url: builtins.str
    """Connection url i.e. some_address:optional_port"""
    username_secret_name: builtins.str
    """Jdbc username secret service secret name"""
    password_secret_name: builtins.str
    """Jdbc password secret service secret name"""
    db_table: builtins.str
    """The database and table i.e. database1.some_table"""
    query: builtins.str
    """Query to run before a casual select runs"""
    @property
    def mysqlSource(self) -> global___MysqlSource: ...
    @property
    def postgresqlSource(self) -> global___PostgresqlSource: ...
    @property
    def redshiftSource(self) -> global___RedshiftSource: ...
    @property
    def athenaSource(self) -> global___AthenaSourceV1: ...
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        username_secret_name: builtins.str = ...,
        password_secret_name: builtins.str = ...,
        db_table: builtins.str = ...,
        query: builtins.str = ...,
        mysqlSource: global___MysqlSource | None = ...,
        postgresqlSource: global___PostgresqlSource | None = ...,
        redshiftSource: global___RedshiftSource | None = ...,
        athenaSource: global___AthenaSourceV1 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["athenaSource", b"athenaSource", "mysqlSource", b"mysqlSource", "postgresqlSource", b"postgresqlSource", "redshiftSource", b"redshiftSource", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["athenaSource", b"athenaSource", "db_table", b"db_table", "mysqlSource", b"mysqlSource", "password_secret_name", b"password_secret_name", "postgresqlSource", b"postgresqlSource", "query", b"query", "redshiftSource", b"redshiftSource", "type", b"type", "url", b"url", "username_secret_name", b"username_secret_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["mysqlSource", "postgresqlSource", "redshiftSource", "athenaSource"] | None: ...

global___JdbcSource = JdbcSource

class MysqlSource(google.protobuf.message.Message):
    """MySQL source"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MysqlSource = MysqlSource

class PostgresqlSource(google.protobuf.message.Message):
    """PostgreSQL source"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PostgresqlSource = PostgresqlSource

class ClickhouseSource(google.protobuf.message.Message):
    """ClickHouse source"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    USERNAME_SECRET_NAME_FIELD_NUMBER: builtins.int
    PASSWORD_SECRET_NAME_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    SQL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """Connection URL i.e. some_address:optional_port/db_name"""
    username_secret_name: builtins.str
    """Username secret service secret name"""
    password_secret_name: builtins.str
    """Password secret service secret name"""
    table: builtins.str
    """The table to load"""
    sql: builtins.str
    """The query to run"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        username_secret_name: builtins.str = ...,
        password_secret_name: builtins.str = ...,
        table: builtins.str = ...,
        sql: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["query_type", b"query_type", "sql", b"sql", "table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["password_secret_name", b"password_secret_name", "query_type", b"query_type", "sql", b"sql", "table", b"table", "url", b"url", "username_secret_name", b"username_secret_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["query_type", b"query_type"]) -> typing_extensions.Literal["table", "sql"] | None: ...

global___ClickhouseSource = ClickhouseSource

class RedshiftSource(google.protobuf.message.Message):
    """Redshift batch source"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DB_USER_FIELD_NUMBER: builtins.int
    IAM_ROLE_ARN_FIELD_NUMBER: builtins.int
    ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
    SECRET_ACCESS_KEY_FIELD_NUMBER: builtins.int
    db_user: builtins.str
    """The user that will connect to the db"""
    iam_role_arn: builtins.str
    """IAM Role ARN to create STS with"""
    access_key_id: builtins.str
    """Aws access key id"""
    secret_access_key: builtins.str
    """Aws secret access key"""
    def __init__(
        self,
        *,
        db_user: builtins.str = ...,
        iam_role_arn: builtins.str = ...,
        access_key_id: builtins.str = ...,
        secret_access_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key_id", b"access_key_id", "db_user", b"db_user", "iam_role_arn", b"iam_role_arn", "secret_access_key", b"secret_access_key"]) -> None: ...

global___RedshiftSource = RedshiftSource

class AthenaSourceV1(google.protobuf.message.Message):
    """Athena batch source"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AWS_REGION_FIELD_NUMBER: builtins.int
    AWS_AUTHENTICATION_FIELD_NUMBER: builtins.int
    S3_OUTPUT_LOCATION_FIELD_NUMBER: builtins.int
    DATE_PARTITION_COLUMNS_FIELD_NUMBER: builtins.int
    TIME_FRAGMENTED_PARTITION_COLUMNS_FIELD_NUMBER: builtins.int
    WORKGROUP_FIELD_NUMBER: builtins.int
    aws_region: builtins.str
    """aws region"""
    @property
    def aws_authentication(self) -> global___AwsAuthentication:
        """Authentication method"""
    s3_output_location: builtins.str
    """S3 Output Location for the query results"""
    @property
    def date_partition_columns(self) -> global___DatePartitionColumns: ...
    @property
    def time_fragmented_partition_columns(self) -> global___TimeFragmentedPartitionColumns: ...
    workgroup: builtins.str
    def __init__(
        self,
        *,
        aws_region: builtins.str = ...,
        aws_authentication: global___AwsAuthentication | None = ...,
        s3_output_location: builtins.str = ...,
        date_partition_columns: global___DatePartitionColumns | None = ...,
        time_fragmented_partition_columns: global___TimeFragmentedPartitionColumns | None = ...,
        workgroup: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_authentication", b"aws_authentication", "date_partition_columns", b"date_partition_columns", "optional_workgroup", b"optional_workgroup", "time_fragmented_partition_columns", b"time_fragmented_partition_columns", "time_partition_columns", b"time_partition_columns", "workgroup", b"workgroup"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_authentication", b"aws_authentication", "aws_region", b"aws_region", "date_partition_columns", b"date_partition_columns", "optional_workgroup", b"optional_workgroup", "s3_output_location", b"s3_output_location", "time_fragmented_partition_columns", b"time_fragmented_partition_columns", "time_partition_columns", b"time_partition_columns", "workgroup", b"workgroup"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_workgroup", b"optional_workgroup"]) -> typing_extensions.Literal["workgroup"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["time_partition_columns", b"time_partition_columns"]) -> typing_extensions.Literal["date_partition_columns", "time_fragmented_partition_columns"] | None: ...

global___AthenaSourceV1 = AthenaSourceV1

class DatePartitionColumns(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATE_COLUMN_NAME_FIELD_NUMBER: builtins.int
    DATE_FORMAT_FIELD_NUMBER: builtins.int
    date_column_name: builtins.str
    """Date partition column name"""
    date_format: builtins.str
    """Date partition column format (%Y-%m-%d | %Y%m%d...)"""
    def __init__(
        self,
        *,
        date_column_name: builtins.str = ...,
        date_format: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["date_column_name", b"date_column_name", "date_format", b"date_format"]) -> None: ...

global___DatePartitionColumns = DatePartitionColumns

class TimeFragmentedPartitionColumns(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    YEAR_PARTITION_COLUMN_FIELD_NUMBER: builtins.int
    MONTH_PARTITION_COLUMN_FIELD_NUMBER: builtins.int
    DAY_PARTITION_COLUMN_FIELD_NUMBER: builtins.int
    @property
    def year_partition_column(self) -> global___YearFragmentColumn:
        """Year partition column"""
    @property
    def month_partition_column(self) -> global___MonthFragmentColumn: ...
    @property
    def day_partition_column(self) -> global___DayFragmentColumn: ...
    def __init__(
        self,
        *,
        year_partition_column: global___YearFragmentColumn | None = ...,
        month_partition_column: global___MonthFragmentColumn | None = ...,
        day_partition_column: global___DayFragmentColumn | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["day_partition", b"day_partition", "day_partition_column", b"day_partition_column", "month_partition", b"month_partition", "month_partition_column", b"month_partition_column", "year_partition_column", b"year_partition_column"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["day_partition", b"day_partition", "day_partition_column", b"day_partition_column", "month_partition", b"month_partition", "month_partition_column", b"month_partition_column", "year_partition_column", b"year_partition_column"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["day_partition", b"day_partition"]) -> typing_extensions.Literal["day_partition_column"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["month_partition", b"month_partition"]) -> typing_extensions.Literal["month_partition_column"] | None: ...

global___TimeFragmentedPartitionColumns = TimeFragmentedPartitionColumns

class YearFragmentColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMN_NAME_FIELD_NUMBER: builtins.int
    NUMERIC_COLUMN_REPRESENTATION_FIELD_NUMBER: builtins.int
    column_name: builtins.str
    """Column name"""
    @property
    def numeric_column_representation(self) -> global___NumericColumnRepresentation:
        """Numeric year column representation supports: '2022' | 2022 for year 2022"""
    def __init__(
        self,
        *,
        column_name: builtins.str = ...,
        numeric_column_representation: global___NumericColumnRepresentation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["column_representation", b"column_representation", "numeric_column_representation", b"numeric_column_representation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["column_name", b"column_name", "column_representation", b"column_representation", "numeric_column_representation", b"numeric_column_representation"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["column_representation", b"column_representation"]) -> typing_extensions.Literal["numeric_column_representation"] | None: ...

global___YearFragmentColumn = YearFragmentColumn

class MonthFragmentColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMN_NAME_FIELD_NUMBER: builtins.int
    NUMERIC_COLUMN_REPRESENTATION_FIELD_NUMBER: builtins.int
    TEXTUAL_COLUMN_REPRESENTATION_FIELD_NUMBER: builtins.int
    column_name: builtins.str
    """Column name"""
    @property
    def numeric_column_representation(self) -> global___NumericColumnRepresentation:
        """Numeric month column representation supports: '1' | '01' | 1   for january"""
    @property
    def textual_column_representation(self) -> global___TextualColumnRepresentation:
        """Textual month column representation supports: 'Jan' | 'January' and is not case sensative"""
    def __init__(
        self,
        *,
        column_name: builtins.str = ...,
        numeric_column_representation: global___NumericColumnRepresentation | None = ...,
        textual_column_representation: global___TextualColumnRepresentation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["column_representation", b"column_representation", "numeric_column_representation", b"numeric_column_representation", "textual_column_representation", b"textual_column_representation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["column_name", b"column_name", "column_representation", b"column_representation", "numeric_column_representation", b"numeric_column_representation", "textual_column_representation", b"textual_column_representation"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["column_representation", b"column_representation"]) -> typing_extensions.Literal["numeric_column_representation", "textual_column_representation"] | None: ...

global___MonthFragmentColumn = MonthFragmentColumn

class DayFragmentColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMN_NAME_FIELD_NUMBER: builtins.int
    NUMERIC_COLUMN_REPRESENTATION_FIELD_NUMBER: builtins.int
    column_name: builtins.str
    """Column name"""
    @property
    def numeric_column_representation(self) -> global___NumericColumnRepresentation:
        """Numeric day column representation supports: '1' | '01' | 1 for 1st day of the month"""
    def __init__(
        self,
        *,
        column_name: builtins.str = ...,
        numeric_column_representation: global___NumericColumnRepresentation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["column_representation", b"column_representation", "numeric_column_representation", b"numeric_column_representation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["column_name", b"column_name", "column_representation", b"column_representation", "numeric_column_representation", b"numeric_column_representation"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["column_representation", b"column_representation"]) -> typing_extensions.Literal["numeric_column_representation"] | None: ...

global___DayFragmentColumn = DayFragmentColumn

class NumericColumnRepresentation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NumericColumnRepresentation = NumericColumnRepresentation

class TextualColumnRepresentation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___TextualColumnRepresentation = TextualColumnRepresentation

class AthenaSource(google.protobuf.message.Message):
    """Athena batch source"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Athena DB name"""
    table: builtins.str
    """Athena DB table"""
    def __init__(
        self,
        *,
        database: builtins.str = ...,
        table: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["database", b"database", "table", b"table"]) -> None: ...

global___AthenaSource = AthenaSource

class BigquerySource(google.protobuf.message.Message):
    """Bigquery batch source"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREDENTIALS_SECRET_NAME_FIELD_NUMBER: builtins.int
    DATASET_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PARENT_PROJECT_FIELD_NUMBER: builtins.int
    SQL_FIELD_NUMBER: builtins.int
    VIEWS_ENABLED_FIELD_NUMBER: builtins.int
    MATERIALIZATION_DATASET_FIELD_NUMBER: builtins.int
    MATERIALIZATION_PROJECT_FIELD_NUMBER: builtins.int
    MATERIALIZATION_EXPIRATION_TIME_IN_MINUTES_FIELD_NUMBER: builtins.int
    credentials_secret_name: builtins.str
    """Qwak secret name of the credentials json used to authenticate with big query"""
    dataset: builtins.str
    """dataset [optional] - not needed in case sql flow is given"""
    table: builtins.str
    """table [optional] - not needed in case sql flow is given"""
    project: builtins.str
    """project where the table sits [optional] (defaults to the project of the credentials)"""
    parent_project: builtins.str
    """parent project - project used for billing [optional] (defaults to the project of the credentials)"""
    sql: builtins.str
    """sql [optional] - run an sql on top of the data source, if set:
    views_enabled must be true
    materialization_dataset must be set to a dataset where the GCP user has table creation permission
    """
    views_enabled: builtins.bool
    """views enabled - enable reading views [optional] (default to false)"""
    materialization_dataset: builtins.str
    """materialization params became deprecated due to using big query python client instead of the spark connector for sql flow
    materialization dataset - dataset to materialize views in [optional] (defaults the the dataset of the source)
    """
    materialization_project: builtins.str
    """materialization project - project to materialize views in [optional] (defaults the the project of the source)"""
    materialization_expiration_time_in_minutes: builtins.str
    """materialization expiration time in minutes - for how long to keep the view [optional] defaults to 24h"""
    def __init__(
        self,
        *,
        credentials_secret_name: builtins.str = ...,
        dataset: builtins.str = ...,
        table: builtins.str = ...,
        project: builtins.str = ...,
        parent_project: builtins.str = ...,
        sql: builtins.str = ...,
        views_enabled: builtins.bool = ...,
        materialization_dataset: builtins.str = ...,
        materialization_project: builtins.str = ...,
        materialization_expiration_time_in_minutes: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials_secret_name", b"credentials_secret_name", "dataset", b"dataset", "materialization_dataset", b"materialization_dataset", "materialization_expiration_time_in_minutes", b"materialization_expiration_time_in_minutes", "materialization_project", b"materialization_project", "parent_project", b"parent_project", "project", b"project", "sql", b"sql", "table", b"table", "views_enabled", b"views_enabled"]) -> None: ...

global___BigquerySource = BigquerySource

class CsvSource(google.protobuf.message.Message):
    """Csv batch source"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    QUOTE_CHARACTER_FIELD_NUMBER: builtins.int
    ESCAPE_CHARACTER_FIELD_NUMBER: builtins.int
    FILESYSTEM_CONFIGURATION_FIELD_NUMBER: builtins.int
    path: builtins.str
    """Csv path"""
    quote_character: builtins.str
    """Quote character for csv parsing (defaults to "). meaning string enclosed by "I am some, string" will be read as 1 object even if there are , inside"""
    escape_character: builtins.str
    """Escape character to the quote character (defaults to "). meaning that a preceding " to the quote character i.e "" the quoting will be ignored"""
    @property
    def filesystem_configuration(self) -> global___FileSystemConfiguration:
        """File system configuration"""
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        quote_character: builtins.str = ...,
        escape_character: builtins.str = ...,
        filesystem_configuration: global___FileSystemConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filesystem_configuration", b"filesystem_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["escape_character", b"escape_character", "filesystem_configuration", b"filesystem_configuration", "path", b"path", "quote_character", b"quote_character"]) -> None: ...

global___CsvSource = CsvSource

class MongoSource(google.protobuf.message.Message):
    """Mongo batch source"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTS_FIELD_NUMBER: builtins.int
    USERNAME_SECRET_NAME_FIELD_NUMBER: builtins.int
    PASSWORD_SECRET_NAME_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    COLLECTION_FIELD_NUMBER: builtins.int
    CONNECTION_PARAMS_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    hosts: builtins.str
    """Mongo host address"""
    username_secret_name: builtins.str
    """Mongo username"""
    password_secret_name: builtins.str
    """Mongo password secret name"""
    database: builtins.str
    """Mongo data base name"""
    collection: builtins.str
    """Mongo collection name"""
    connection_params: builtins.str
    """Mongo connection parameters"""
    protocol: builtins.str
    """Mongo protocol, defaults to mongodb"""
    def __init__(
        self,
        *,
        hosts: builtins.str = ...,
        username_secret_name: builtins.str = ...,
        password_secret_name: builtins.str = ...,
        database: builtins.str = ...,
        collection: builtins.str = ...,
        connection_params: builtins.str = ...,
        protocol: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection", b"collection", "connection_params", b"connection_params", "database", b"database", "hosts", b"hosts", "password_secret_name", b"password_secret_name", "protocol", b"protocol", "username_secret_name", b"username_secret_name"]) -> None: ...

global___MongoSource = MongoSource

class SnowflakeSource(google.protobuf.message.Message):
    """Snowflake batch source"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    USERNAME_SECRET_NAME_FIELD_NUMBER: builtins.int
    PASSWORD_SECRET_NAME_FIELD_NUMBER: builtins.int
    PEM_PRIVATE_KEY_SECRET_NAME_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    WAREHOUSE_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    host: builtins.str
    """SF host address <account_identifier>.snowflakecomputing.com]"""
    username_secret_name: builtins.str
    """SF username secret name"""
    password_secret_name: builtins.str
    """SF password secret name"""
    pem_private_key_secret_name: builtins.str
    """SF pem formatted private key secret name"""
    database: builtins.str
    """SF database name"""
    schema: builtins.str
    """SF schema name"""
    warehouse: builtins.str
    """SF warehouse name"""
    table: builtins.str
    """SF table name, can not be set together with query"""
    query: builtins.str
    """SF query, can not be set together with table"""
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        username_secret_name: builtins.str = ...,
        password_secret_name: builtins.str = ...,
        pem_private_key_secret_name: builtins.str = ...,
        database: builtins.str = ...,
        schema: builtins.str = ...,
        warehouse: builtins.str = ...,
        table: builtins.str = ...,
        query: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_secret", b"auth_secret", "password_secret_name", b"password_secret_name", "pem_private_key_secret_name", b"pem_private_key_secret_name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_secret", b"auth_secret", "database", b"database", "host", b"host", "password_secret_name", b"password_secret_name", "pem_private_key_secret_name", b"pem_private_key_secret_name", "query", b"query", "schema", b"schema", "table", b"table", "username_secret_name", b"username_secret_name", "warehouse", b"warehouse"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth_secret", b"auth_secret"]) -> typing_extensions.Literal["password_secret_name", "pem_private_key_secret_name"] | None: ...

global___SnowflakeSource = SnowflakeSource

class ParquetSource(google.protobuf.message.Message):
    """Parquet batch source"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    FILESYSTEM_CONFIGURATION_FIELD_NUMBER: builtins.int
    path: builtins.str
    """Path to parquet file"""
    @property
    def filesystem_configuration(self) -> global___FileSystemConfiguration:
        """File system configuration"""
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        filesystem_configuration: global___FileSystemConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filesystem_configuration", b"filesystem_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filesystem_configuration", b"filesystem_configuration", "path", b"path"]) -> None: ...

global___ParquetSource = ParquetSource

class VerticaSource(google.protobuf.message.Message):
    """Vertica batch source"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    USERNAME_SECRET_NAME_FIELD_NUMBER: builtins.int
    PASSWORD_SECRET_NAME_FIELD_NUMBER: builtins.int
    host: builtins.str
    """Vertica host address, without port"""
    port: builtins.int
    """Vertica port number"""
    database: builtins.str
    """Vertica database name"""
    schema: builtins.str
    """Vertica schema name"""
    table: builtins.str
    """Vertica table name"""
    username_secret_name: builtins.str
    """Vertica username qwak secret name"""
    password_secret_name: builtins.str
    """Vertica password qwak secret name"""
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        port: builtins.int = ...,
        database: builtins.str = ...,
        schema: builtins.str = ...,
        table: builtins.str = ...,
        username_secret_name: builtins.str = ...,
        password_secret_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["database", b"database", "host", b"host", "password_secret_name", b"password_secret_name", "port", b"port", "schema", b"schema", "table", b"table", "username_secret_name", b"username_secret_name"]) -> None: ...

global___VerticaSource = VerticaSource

class ElasticsearchSource(google.protobuf.message.Message):
    """Elasticsearch batch source"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODES_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    EXCLUDE_FIELDS_FIELD_NUMBER: builtins.int
    PARSE_DATES_FIELD_NUMBER: builtins.int
    USERNAME_SECRET_NAME_FIELD_NUMBER: builtins.int
    PASSWORD_SECRET_NAME_FIELD_NUMBER: builtins.int
    nodes: builtins.str
    """List of node addresses, port can be specified per node here e.g. 1.1.1.1:9200 - takes precedence over `port`"""
    port: builtins.int
    """Port"""
    resource: builtins.str
    """Resource to query for, i.e. index name"""
    query: builtins.str
    """Elasticsearch query to run on top of the data source"""
    exclude_fields: builtins.str
    """List of fields to exclude"""
    parse_dates: builtins.bool
    """Flag determining if date fields should be parsed as dates [defaults to True]"""
    username_secret_name: builtins.str
    """Elasticsearch username qwak secret name"""
    password_secret_name: builtins.str
    """Elasticsearch password qwak secret name"""
    def __init__(
        self,
        *,
        nodes: builtins.str = ...,
        port: builtins.int = ...,
        resource: builtins.str = ...,
        query: builtins.str = ...,
        exclude_fields: builtins.str = ...,
        parse_dates: builtins.bool = ...,
        username_secret_name: builtins.str = ...,
        password_secret_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclude_fields", b"exclude_fields", "nodes", b"nodes", "parse_dates", b"parse_dates", "password_secret_name", b"password_secret_name", "port", b"port", "query", b"query", "resource", b"resource", "username_secret_name", b"username_secret_name"]) -> None: ...

global___ElasticsearchSource = ElasticsearchSource

class CatalogSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    UNITYCATALOGSOURCE_FIELD_NUMBER: builtins.int
    url: builtins.str
    """Connection url i.e https://<workspace-instance-name>.<domain-name>"""
    table: builtins.str
    """Catalog table including schema"""
    query: builtins.str
    """Catalog query"""
    @property
    def unityCatalogSource(self) -> global___UnityCatalogSource:
        """Unity Catalog source"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        table: builtins.str = ...,
        query: builtins.str = ...,
        unityCatalogSource: global___UnityCatalogSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["query", b"query", "select_type", b"select_type", "table", b"table", "type", b"type", "unityCatalogSource", b"unityCatalogSource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["query", b"query", "select_type", b"select_type", "table", b"table", "type", b"type", "unityCatalogSource", b"unityCatalogSource", "url", b"url"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["select_type", b"select_type"]) -> typing_extensions.Literal["table", "query"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["unityCatalogSource"] | None: ...

global___CatalogSource = CatalogSource

class UnityCatalogSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATALOG_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    PERSONAL_ACCESS_TOKEN_SECRET_NAME_FIELD_NUMBER: builtins.int
    OAUTH2_FIELD_NUMBER: builtins.int
    catalog: builtins.str
    """Unity Catalog catalog name"""
    schema: builtins.str
    """Unity Catalog schema name"""
    personal_access_token_secret_name: builtins.str
    @property
    def oauth2(self) -> global___Oauth2: ...
    def __init__(
        self,
        *,
        catalog: builtins.str = ...,
        schema: builtins.str = ...,
        personal_access_token_secret_name: builtins.str = ...,
        oauth2: global___Oauth2 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "oauth2", b"oauth2", "personal_access_token_secret_name", b"personal_access_token_secret_name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "catalog", b"catalog", "oauth2", b"oauth2", "personal_access_token_secret_name", b"personal_access_token_secret_name", "schema", b"schema"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth_type", b"auth_type"]) -> typing_extensions.Literal["personal_access_token_secret_name", "oauth2"] | None: ...

global___UnityCatalogSource = UnityCatalogSource

class Oauth2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_SECRET_NAME_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_SECRET_NAME_FIELD_NUMBER: builtins.int
    client_id_secret_name: builtins.str
    """client id"""
    client_secret_secret_name: builtins.str
    """client secret"""
    def __init__(
        self,
        *,
        client_id_secret_name: builtins.str = ...,
        client_secret_secret_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id_secret_name", b"client_id_secret_name", "client_secret_secret_name", b"client_secret_secret_name"]) -> None: ...

global___Oauth2 = Oauth2

class FeaturesetOfflineSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALIAS_FIELD_NUMBER: builtins.int
    alias: builtins.str
    """Featureset alias as referred to in the transformation"""
    def __init__(
        self,
        *,
        alias: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alias", b"alias"]) -> None: ...

global___FeaturesetOfflineSource = FeaturesetOfflineSource

class AwsAuthentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AWS_ASSUME_ROLE_AUTHENTICATION_FIELD_NUMBER: builtins.int
    AWS_STATIC_CREDENTIALS_AUTHENTICATION_FIELD_NUMBER: builtins.int
    @property
    def aws_assume_role_authentication(self) -> global___AwsAssumeRoleAuthentication: ...
    @property
    def aws_static_credentials_authentication(self) -> global___AwsCredentialsAuthentication: ...
    def __init__(
        self,
        *,
        aws_assume_role_authentication: global___AwsAssumeRoleAuthentication | None = ...,
        aws_static_credentials_authentication: global___AwsCredentialsAuthentication | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_assume_role_authentication", b"aws_assume_role_authentication", "aws_static_credentials_authentication", b"aws_static_credentials_authentication", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_assume_role_authentication", b"aws_assume_role_authentication", "aws_static_credentials_authentication", b"aws_static_credentials_authentication", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["aws_assume_role_authentication", "aws_static_credentials_authentication"] | None: ...

global___AwsAuthentication = AwsAuthentication

class AwsAssumeRoleAuthentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_ARN_FIELD_NUMBER: builtins.int
    role_arn: builtins.str
    """Role to assume"""
    def __init__(
        self,
        *,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["role_arn", b"role_arn"]) -> None: ...

global___AwsAssumeRoleAuthentication = AwsAssumeRoleAuthentication

class AwsCredentialsAuthentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_SECRET_NAME_FIELD_NUMBER: builtins.int
    SECRET_KEY_SECRET_NAME_FIELD_NUMBER: builtins.int
    access_key_secret_name: builtins.str
    """AWS access key"""
    secret_key_secret_name: builtins.str
    """AWS secret key"""
    def __init__(
        self,
        *,
        access_key_secret_name: builtins.str = ...,
        secret_key_secret_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key_secret_name", b"access_key_secret_name", "secret_key_secret_name", b"secret_key_secret_name"]) -> None: ...

global___AwsCredentialsAuthentication = AwsCredentialsAuthentication

class GcsUnauthenticated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GcsUnauthenticated = GcsUnauthenticated

class GcsUserCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_SECRET_NAME_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_SECRET_NAME_FIELD_NUMBER: builtins.int
    REFRESH_TOKEN_SECRET_NAME_FIELD_NUMBER: builtins.int
    client_id_secret_name: builtins.str
    """GCS client id"""
    client_secret_secret_name: builtins.str
    """GCS client secret"""
    refresh_token_secret_name: builtins.str
    """GCS refresh token"""
    def __init__(
        self,
        *,
        client_id_secret_name: builtins.str = ...,
        client_secret_secret_name: builtins.str = ...,
        refresh_token_secret_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id_secret_name", b"client_id_secret_name", "client_secret_secret_name", b"client_secret_secret_name", "refresh_token_secret_name", b"refresh_token_secret_name"]) -> None: ...

global___GcsUserCredentials = GcsUserCredentials

class GcsServiceAccountImpersonation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_USER_FIELD_NUMBER: builtins.int
    service_account_user: builtins.str
    """User's GCS user email"""
    def __init__(
        self,
        *,
        service_account_user: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service_account_user", b"service_account_user"]) -> None: ...

global___GcsServiceAccountImpersonation = GcsServiceAccountImpersonation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import qwak.builds.build_values_pb2
import qwak.fitness_service.fitness_pb2
import qwak.user_application.common.v0.resources_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MemoryUnit:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MemoryUnitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MemoryUnit.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_MEMORY_UNIT: _MemoryUnit.ValueType  # 0
    MIB: _MemoryUnit.ValueType  # 1
    GIB: _MemoryUnit.ValueType  # 2

class MemoryUnit(_MemoryUnit, metaclass=_MemoryUnitEnumTypeWrapper): ...

UNKNOWN_MEMORY_UNIT: MemoryUnit.ValueType  # 0
MIB: MemoryUnit.ValueType  # 1
GIB: MemoryUnit.ValueType  # 2
global___MemoryUnit = MemoryUnit

class _GpuType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GpuTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GpuType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID: _GpuType.ValueType  # 0
    NVIDIA_K80: _GpuType.ValueType  # 1
    NVIDIA_V100: _GpuType.ValueType  # 2
    NVIDIA_A100: _GpuType.ValueType  # 3
    NVIDIA_T4: _GpuType.ValueType  # 4
    NVIDIA_A10G: _GpuType.ValueType  # 5
    NVIDIA_L4: _GpuType.ValueType  # 6
    NVIDIA_T4_1_4_15: _GpuType.ValueType  # 7
    """More specific node types
    t4.xl
    """
    NVIDIA_T4_1_8_30: _GpuType.ValueType  # 8
    """t4.2xl"""
    NVIDIA_T4_1_16_60: _GpuType.ValueType  # 9
    """t4.4xl"""
    NVIDIA_A100_80GB_8_96_1360: _GpuType.ValueType  # 10
    """a100.8xl"""
    NVIDIA_V100_1_8_52: _GpuType.ValueType  # 11
    """a100.xl"""
    NVIDIA_V100_4_32_208: _GpuType.ValueType  # 12
    """v100.4xl"""
    NVIDIA_H100_NVL: _GpuType.ValueType  # 13
    """H100 NVL XLarge"""
    NVIDIA_A10: _GpuType.ValueType  # 14
    """A10 Small"""
    NVIDIA_H100_SXM: _GpuType.ValueType  # 15
    """H100 SXM 8XLarge"""
    NVIDIA_H100_40GB: _GpuType.ValueType  # 16
    """H100 40GB 8XLarge"""
    NVIDIA_H100_80GB: _GpuType.ValueType  # 17
    """H100 80GB 8XLarge"""
    NVIDIA_M60: _GpuType.ValueType  # 18
    """M60 XLarge"""

class GpuType(_GpuType, metaclass=_GpuTypeEnumTypeWrapper): ...

INVALID: GpuType.ValueType  # 0
NVIDIA_K80: GpuType.ValueType  # 1
NVIDIA_V100: GpuType.ValueType  # 2
NVIDIA_A100: GpuType.ValueType  # 3
NVIDIA_T4: GpuType.ValueType  # 4
NVIDIA_A10G: GpuType.ValueType  # 5
NVIDIA_L4: GpuType.ValueType  # 6
NVIDIA_T4_1_4_15: GpuType.ValueType  # 7
"""More specific node types
t4.xl
"""
NVIDIA_T4_1_8_30: GpuType.ValueType  # 8
"""t4.2xl"""
NVIDIA_T4_1_16_60: GpuType.ValueType  # 9
"""t4.4xl"""
NVIDIA_A100_80GB_8_96_1360: GpuType.ValueType  # 10
"""a100.8xl"""
NVIDIA_V100_1_8_52: GpuType.ValueType  # 11
"""a100.xl"""
NVIDIA_V100_4_32_208: GpuType.ValueType  # 12
"""v100.4xl"""
NVIDIA_H100_NVL: GpuType.ValueType  # 13
"""H100 NVL XLarge"""
NVIDIA_A10: GpuType.ValueType  # 14
"""A10 Small"""
NVIDIA_H100_SXM: GpuType.ValueType  # 15
"""H100 SXM 8XLarge"""
NVIDIA_H100_40GB: GpuType.ValueType  # 16
"""H100 40GB 8XLarge"""
NVIDIA_H100_80GB: GpuType.ValueType  # 17
"""H100 80GB 8XLarge"""
NVIDIA_M60: GpuType.ValueType  # 18
"""M60 XLarge"""
global___GpuType = GpuType

class _DataColumnType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DataColumnTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DataColumnType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_COLUMN_TYPE: _DataColumnType.ValueType  # 0
    OBJECT: _DataColumnType.ValueType  # 1
    INT: _DataColumnType.ValueType  # 2
    FLOAT: _DataColumnType.ValueType  # 3
    BOOLEAN: _DataColumnType.ValueType  # 4
    DATETIME: _DataColumnType.ValueType  # 5

class DataColumnType(_DataColumnType, metaclass=_DataColumnTypeEnumTypeWrapper):
    """Pandas Types."""

INVALID_COLUMN_TYPE: DataColumnType.ValueType  # 0
OBJECT: DataColumnType.ValueType  # 1
INT: DataColumnType.ValueType  # 2
FLOAT: DataColumnType.ValueType  # 3
BOOLEAN: DataColumnType.ValueType  # 4
DATETIME: DataColumnType.ValueType  # 5
global___DataColumnType = DataColumnType

class _BaseDockerImageType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BaseDockerImageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BaseDockerImageType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_BASE_DOCKER_IMAGE_TYPE: _BaseDockerImageType.ValueType  # 0
    CPU: _BaseDockerImageType.ValueType  # 1
    GPU: _BaseDockerImageType.ValueType  # 2

class BaseDockerImageType(_BaseDockerImageType, metaclass=_BaseDockerImageTypeEnumTypeWrapper): ...

UNKNOWN_BASE_DOCKER_IMAGE_TYPE: BaseDockerImageType.ValueType  # 0
CPU: BaseDockerImageType.ValueType  # 1
GPU: BaseDockerImageType.ValueType  # 2
global___BaseDockerImageType = BaseDockerImageType

class RemoteBuildSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_PROPERTIES_FIELD_NUMBER: builtins.int
    BUILD_ENV_FIELD_NUMBER: builtins.int
    CPU_RESOURCES_FIELD_NUMBER: builtins.int
    GPU_RESOURCES_FIELD_NUMBER: builtins.int
    CLIENT_POD_COMPUTE_RESOURCES_FIELD_NUMBER: builtins.int
    VERBOSE_FIELD_NUMBER: builtins.int
    BUILD_CODE_PATH_FIELD_NUMBER: builtins.int
    BUILD_CONFIG_FIELD_NUMBER: builtins.int
    BUILD_V1_FLAG_FIELD_NUMBER: builtins.int
    BUILD_PROPERTIES_V1_FIELD_NUMBER: builtins.int
    BUILD_STEPS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    SDK_VERSION_FIELD_NUMBER: builtins.int
    PURCHASE_OPTION_FIELD_NUMBER: builtins.int
    BUILD_DESTINED_IMAGE_FIELD_NUMBER: builtins.int
    PROVISION_INSTANCE_TIMEOUT_FIELD_NUMBER: builtins.int
    JFROG_TOKEN_ID_FIELD_NUMBER: builtins.int
    ARTIFACTORY_PROJECT_KEY_FIELD_NUMBER: builtins.int
    MODEL_VERSION_ID_FIELD_NUMBER: builtins.int
    MODEL_GROUP_NAME_FIELD_NUMBER: builtins.int
    @property
    def build_properties(self) -> global___BuildProperties: ...
    @property
    def build_env(self) -> global___BuildEnv: ...
    @property
    def cpu_resources(self) -> global___CpuResources:
        """CPU Properties"""
    @property
    def gpu_resources(self) -> global___GpuResources:
        """GPU Properties"""
    @property
    def client_pod_compute_resources(self) -> qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources:
        """Build pod compute resources"""
    verbose: builtins.int
    """Logs verbose mode 0: warning, 1: info, 2: debug (by qwak.tools.logger.py VERBOSITY_LEVEL_MAPPING from qwak-sdk)"""
    build_code_path: builtins.str
    """The saved code path."""
    build_config: builtins.str
    """The build configuration yaml as json"""
    build_v1_flag: builtins.bool
    """Build v1 flag"""
    @property
    def build_properties_v1(self) -> global___BuildPropertiesV1:
        """Build Properties V1"""
    @property
    def build_steps(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The build steps the build will handle"""
    environment_id: builtins.str
    """The environment to build on"""
    sdk_version: builtins.str
    """The build SDK version"""
    purchase_option: qwak.fitness_service.fitness_pb2.PurchaseOption.ValueType
    """Purchase option for the build"""
    build_destined_image: builtins.str
    provision_instance_timeout: builtins.int
    """Timeout in minutes of the provisioning build step"""
    jfrog_token_id: builtins.str
    """JFrog token id for token generation"""
    artifactory_project_key: builtins.str
    """Artifactory project key"""
    model_version_id: builtins.str
    """Optional - The model version's id used for the build"""
    model_group_name: builtins.str
    """Human readable model group identifier (e.g., "my-model-group").
    This is the display name, not the UUID.
    """
    def __init__(
        self,
        *,
        build_properties: global___BuildProperties | None = ...,
        build_env: global___BuildEnv | None = ...,
        cpu_resources: global___CpuResources | None = ...,
        gpu_resources: global___GpuResources | None = ...,
        client_pod_compute_resources: qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources | None = ...,
        verbose: builtins.int = ...,
        build_code_path: builtins.str = ...,
        build_config: builtins.str = ...,
        build_v1_flag: builtins.bool = ...,
        build_properties_v1: global___BuildPropertiesV1 | None = ...,
        build_steps: collections.abc.Iterable[builtins.str] | None = ...,
        environment_id: builtins.str = ...,
        sdk_version: builtins.str = ...,
        purchase_option: qwak.fitness_service.fitness_pb2.PurchaseOption.ValueType = ...,
        build_destined_image: builtins.str = ...,
        provision_instance_timeout: builtins.int = ...,
        jfrog_token_id: builtins.str = ...,
        artifactory_project_key: builtins.str = ...,
        model_version_id: builtins.str = ...,
        model_group_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["Resources", b"Resources", "build_env", b"build_env", "build_properties", b"build_properties", "build_properties_v1", b"build_properties_v1", "client_pod_compute_resources", b"client_pod_compute_resources", "cpu_resources", b"cpu_resources", "gpu_resources", b"gpu_resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["Resources", b"Resources", "artifactory_project_key", b"artifactory_project_key", "build_code_path", b"build_code_path", "build_config", b"build_config", "build_destined_image", b"build_destined_image", "build_env", b"build_env", "build_properties", b"build_properties", "build_properties_v1", b"build_properties_v1", "build_steps", b"build_steps", "build_v1_flag", b"build_v1_flag", "client_pod_compute_resources", b"client_pod_compute_resources", "cpu_resources", b"cpu_resources", "environment_id", b"environment_id", "gpu_resources", b"gpu_resources", "jfrog_token_id", b"jfrog_token_id", "model_group_name", b"model_group_name", "model_version_id", b"model_version_id", "provision_instance_timeout", b"provision_instance_timeout", "purchase_option", b"purchase_option", "sdk_version", b"sdk_version", "verbose", b"verbose"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["Resources", b"Resources"]) -> typing_extensions.Literal["cpu_resources", "gpu_resources", "client_pod_compute_resources"] | None: ...

global___RemoteBuildSpec = RemoteBuildSpec

class BuildPropertiesV1(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_CONFIG_URL_FIELD_NUMBER: builtins.int
    QWAK_SDK_WHEEL_URL_FIELD_NUMBER: builtins.int
    QWAK_SDK_VERSION_URL_FIELD_NUMBER: builtins.int
    build_config_url: builtins.str
    """Build V1 - build config url"""
    qwak_sdk_wheel_url: builtins.str
    """Build V1 - qwak-sdk wheel url"""
    qwak_sdk_version_url: builtins.str
    """Build V1 - qwak-sdk version"""
    def __init__(
        self,
        *,
        build_config_url: builtins.str = ...,
        qwak_sdk_wheel_url: builtins.str = ...,
        qwak_sdk_version_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_config_url", b"build_config_url", "qwak_sdk_version_url", b"qwak_sdk_version_url", "qwak_sdk_wheel_url", b"qwak_sdk_wheel_url"]) -> None: ...

global___BuildPropertiesV1 = BuildPropertiesV1

class BuildProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    BRANCH_FIELD_NUMBER: builtins.int
    MODEL_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    MODEL_URI_FIELD_NUMBER: builtins.int
    GPU_COMPATIBLE_FIELD_NUMBER: builtins.int
    BUILD_NAME_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """Build id"""
    branch: builtins.str
    """Branch name. When none provided - 'main' will be the selected branch"""
    model_id: builtins.str
    """Model id"""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Build tags"""
    @property
    def model_uri(self) -> global___ModelUriSpec:
        """Model URI spec"""
    gpu_compatible: builtins.bool
    """Is the build should be GPU compatible"""
    build_name: builtins.str
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
        branch: builtins.str = ...,
        model_id: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        model_uri: global___ModelUriSpec | None = ...,
        gpu_compatible: builtins.bool = ...,
        build_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_uri", b"model_uri"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch", b"branch", "build_id", b"build_id", "build_name", b"build_name", "gpu_compatible", b"gpu_compatible", "model_id", b"model_id", "model_uri", b"model_uri", "tags", b"tags"]) -> None: ...

global___BuildProperties = BuildProperties

class ModelUriSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URI_FIELD_NUMBER: builtins.int
    GIT_BRANCH_FIELD_NUMBER: builtins.int
    GIT_CREDENTIALS_FIELD_NUMBER: builtins.int
    GIT_CREDENTIALS_SECRET_FIELD_NUMBER: builtins.int
    COMMIT_ID_FIELD_NUMBER: builtins.int
    MAIN_DIR_FIELD_NUMBER: builtins.int
    DEPENDENCY_REQUIRED_FOLDERS_FIELD_NUMBER: builtins.int
    uri: builtins.str
    """Model code to build upon, can be a download link or a git repo"""
    git_branch: builtins.str
    """Model code branch to clone"""
    git_credentials: builtins.str
    """Git credentials"""
    git_credentials_secret: builtins.str
    """Secret to fetch git credentials, overrides git_credentials if set"""
    commit_id: builtins.str
    """Commit id - filled when using local model code which is part of a git repo"""
    main_dir: builtins.str
    """Override for main dir of model"""
    @property
    def dependency_required_folders(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Required folders for the model"""
    def __init__(
        self,
        *,
        uri: builtins.str = ...,
        git_branch: builtins.str = ...,
        git_credentials: builtins.str = ...,
        git_credentials_secret: builtins.str = ...,
        commit_id: builtins.str = ...,
        main_dir: builtins.str = ...,
        dependency_required_folders: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["commit_id", b"commit_id", "dependency_required_folders", b"dependency_required_folders", "git_branch", b"git_branch", "git_credentials", b"git_credentials", "git_credentials_secret", b"git_credentials_secret", "main_dir", b"main_dir", "uri", b"uri"]) -> None: ...

global___ModelUriSpec = ModelUriSpec

class BuildEnv(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOCKER_ENV_FIELD_NUMBER: builtins.int
    PYTHON_ENV_FIELD_NUMBER: builtins.int
    @property
    def docker_env(self) -> global___DockerEnv: ...
    @property
    def python_env(self) -> global___PythonEnv: ...
    def __init__(
        self,
        *,
        docker_env: global___DockerEnv | None = ...,
        python_env: global___PythonEnv | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["docker_env", b"docker_env", "python_env", b"python_env"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["docker_env", b"docker_env", "python_env", b"python_env"]) -> None: ...

global___BuildEnv = BuildEnv

class DockerEnv(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_IMAGE_FIELD_NUMBER: builtins.int
    ENV_VARS_FIELD_NUMBER: builtins.int
    NO_CACHE_FIELD_NUMBER: builtins.int
    ASSUMED_IAM_ROLE_ARN_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_KEY_SECRET_NAME_FIELD_NUMBER: builtins.int
    CONTAINER_ENGINE_FIELD_NUMBER: builtins.int
    base_image: builtins.str
    """Base image to use for serving"""
    @property
    def env_vars(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Environment variables for the model code"""
    no_cache: builtins.bool
    """Don't use remote cache to build the images, defaults to use cache,
    if the model dependencies changed significantly it could be faster and better to run with no cache
    """
    assumed_iam_role_arn: builtins.str
    """Custom IAM role to be assumed by model"""
    service_account_key_secret_name: builtins.str
    """Service account key secret name for gcp"""
    @property
    def container_engine(self) -> qwak.builds.build_values_pb2.ContainerEngine:
        """Container engine to use for building and pushing the image (e.g., Docker, Podman)"""
    def __init__(
        self,
        *,
        base_image: builtins.str = ...,
        env_vars: collections.abc.Iterable[builtins.str] | None = ...,
        no_cache: builtins.bool = ...,
        assumed_iam_role_arn: builtins.str = ...,
        service_account_key_secret_name: builtins.str = ...,
        container_engine: qwak.builds.build_values_pb2.ContainerEngine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_engine", b"container_engine"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assumed_iam_role_arn", b"assumed_iam_role_arn", "base_image", b"base_image", "container_engine", b"container_engine", "env_vars", b"env_vars", "no_cache", b"no_cache", "service_account_key_secret_name", b"service_account_key_secret_name"]) -> None: ...

global___DockerEnv = DockerEnv

class PythonEnv(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GIT_CREDENTIALS_FIELD_NUMBER: builtins.int
    GIT_CREDENTIALS_SECRET_FIELD_NUMBER: builtins.int
    QWAK_SDK_VERSION_FIELD_NUMBER: builtins.int
    QWAK_SDK_EXTRA_INDEX_FIELD_NUMBER: builtins.int
    FROGML_CLI_VERSION_FIELD_NUMBER: builtins.int
    FROGML_CLI_EXTRA_INDEX_FIELD_NUMBER: builtins.int
    git_credentials: builtins.str
    """Git credentials"""
    git_credentials_secret: builtins.str
    """Secret to fetch git credentials, overrides git_credentials if set"""
    qwak_sdk_version: builtins.str
    """Qwak sdk version of calling user"""
    qwak_sdk_extra_index: builtins.str
    """Pip extra index url to install qwak-sdk from"""
    frogml_cli_version: builtins.str
    """FrogML cli version of calling user"""
    frogml_cli_extra_index: builtins.str
    """Pip extra index url to install frogml-cli from"""
    def __init__(
        self,
        *,
        git_credentials: builtins.str = ...,
        git_credentials_secret: builtins.str = ...,
        qwak_sdk_version: builtins.str = ...,
        qwak_sdk_extra_index: builtins.str = ...,
        frogml_cli_version: builtins.str = ...,
        frogml_cli_extra_index: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["frogml_cli_extra_index", b"frogml_cli_extra_index", "frogml_cli_version", b"frogml_cli_version", "git_credentials", b"git_credentials", "git_credentials_secret", b"git_credentials_secret", "qwak_sdk_extra_index", b"qwak_sdk_extra_index", "qwak_sdk_version", b"qwak_sdk_version"]) -> None: ...

global___PythonEnv = PythonEnv

class CpuResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPU_FIELD_NUMBER: builtins.int
    MEMORY_AMOUNT_FIELD_NUMBER: builtins.int
    MEMORY_UNITS_FIELD_NUMBER: builtins.int
    cpu: builtins.float
    """Amount of CPU cores"""
    memory_amount: builtins.int
    """Amount of memory"""
    memory_units: global___MemoryUnit.ValueType
    """Units type of memory"""
    def __init__(
        self,
        *,
        cpu: builtins.float = ...,
        memory_amount: builtins.int = ...,
        memory_units: global___MemoryUnit.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu", b"cpu", "memory_amount", b"memory_amount", "memory_units", b"memory_units"]) -> None: ...

global___CpuResources = CpuResources

class GpuResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GPU_TYPE_FIELD_NUMBER: builtins.int
    GPU_AMOUNT_FIELD_NUMBER: builtins.int
    gpu_type: global___GpuType.ValueType
    """The type of the GPU"""
    gpu_amount: builtins.int
    """Amount of GPUs"""
    def __init__(
        self,
        *,
        gpu_type: global___GpuType.ValueType = ...,
        gpu_amount: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gpu_amount", b"gpu_amount", "gpu_type", b"gpu_type"]) -> None: ...

global___GpuResources = GpuResources

class DataTableDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMNS_FIELD_NUMBER: builtins.int
    DATA_FORMAT_FIELD_NUMBER: builtins.int
    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataColumnDefinition]:
        """The columns of the data."""
    @property
    def data_format(self) -> global___DataFormat:
        """How the data as been saved."""
    def __init__(
        self,
        *,
        columns: collections.abc.Iterable[global___DataColumnDefinition] | None = ...,
        data_format: global___DataFormat | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_format", b"data_format"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["columns", b"columns", "data_format", b"data_format"]) -> None: ...

global___DataTableDefinition = DataTableDefinition

class DataColumnDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the column to save."""
    type: global___DataColumnType.ValueType
    """The type of the column."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: global___DataColumnType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___DataColumnDefinition = DataColumnDefinition

class DataFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CSV_FIELD_NUMBER: builtins.int
    @property
    def csv(self) -> global___CsvFormat: ...
    def __init__(
        self,
        *,
        csv: global___CsvFormat | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["csv", b"csv", "format", b"format"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["csv", b"csv", "format", b"format"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["format", b"format"]) -> typing_extensions.Literal["csv"] | None: ...

global___DataFormat = DataFormat

class CsvFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIMITER_FIELD_NUMBER: builtins.int
    QUOTE_CHAR_FIELD_NUMBER: builtins.int
    ESCAPE_CHAR_FIELD_NUMBER: builtins.int
    delimiter: builtins.str
    """Separator character - represent field in the data"""
    quote_char: builtins.str
    """Quote Character"""
    escape_char: builtins.str
    """Escape character - for special character in the data."""
    def __init__(
        self,
        *,
        delimiter: builtins.str = ...,
        quote_char: builtins.str = ...,
        escape_char: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delimiter", b"delimiter", "escape_char", b"escape_char", "quote_char", b"quote_char"]) -> None: ...

global___CsvFormat = CsvFormat

class BuildInitiator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    AUTOMATION_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___UserBuildInitiator: ...
    @property
    def automation(self) -> global___AutomationBuildInitiator: ...
    def __init__(
        self,
        *,
        user: global___UserBuildInitiator | None = ...,
        automation: global___AutomationBuildInitiator | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["Initiator", b"Initiator", "automation", b"automation", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["Initiator", b"Initiator", "automation", b"automation", "user", b"user"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["Initiator", b"Initiator"]) -> typing_extensions.Literal["user", "automation"] | None: ...

global___BuildInitiator = BuildInitiator

class UserBuildInitiator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UserBuildInitiator = UserBuildInitiator

class AutomationBuildInitiator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTOMATION_ID_FIELD_NUMBER: builtins.int
    EXECUTION_ID_FIELD_NUMBER: builtins.int
    AUTOMATION_NAME_FIELD_NUMBER: builtins.int
    automation_id: builtins.str
    """The id of the automation that triggered the build"""
    execution_id: builtins.str
    """The specific execution that trigger the build"""
    automation_name: builtins.str
    """The name of the automation that trigger the build"""
    def __init__(
        self,
        *,
        automation_id: builtins.str = ...,
        execution_id: builtins.str = ...,
        automation_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["automation_id", b"automation_id", "automation_name", b"automation_name", "execution_id", b"execution_id"]) -> None: ...

global___AutomationBuildInitiator = AutomationBuildInitiator



import uuid
from typing import Dict, List, Optional, Set

from _qwak_proto.qwak.administration.authenticated_user.v1.credentials_pb2 import (
    AwsTemporaryCredentials,
)
from _qwak_proto.qwak.batch_job.v1.batch_job_service_pb2 import (
    BatchJobDeploymentSize,
    BatchJobDetails,
    BatchJobMessage,
    BatchJobStatusMessage,
    BatchTaskStatusMessage,
    CancelBatchJobRequest,
    CancelBatchJobResponse,
    CancelWarmupJobRequest,
    CancelWarmupJobResponse,
    ExecutionReportLine,
    GetBatchJobDetailsRequest,
    GetBatchJobDetailsResponse,
    GetBatchJobDownloadDetailsRequest,
    GetBatchJobDownloadDetailsResponse,
    GetBatchJobPreSignedDownloadUrlRequest,
    GetBatchJobPreSignedDownloadUrlResponse,
    GetBatchJobPreSignedUploadUrlRequest,
    GetBatchJobPreSignedUploadUrlResponse,
    GetBatchJobReportRequest,
    GetBatchJobReportResponse,
    GetBatchJobStatusRequest,
    GetBatchJobStatusResponse,
    GetBatchJobUploadDetailsRequest,
    GetBatchJobUploadDetailsResponse,
    ListBatchJobsRequest,
    ListBatchJobsResponse,
    StartBatchJobRequest,
    StartBatchJobResponse,
    StartWarmupJobRequest,
    StartWarmupJobResponse,
    TaskExecutionDetails,
    UpdateTasksDetailsRequest,
    UpdateTasksDetailsResponse,
    BatchTaskDetails,
)
from _qwak_proto.qwak.batch_job.v1.batch_job_service_pb2_grpc import (
    BatchJobManagementServiceServicer,
)
from google.protobuf.timestamp_pb2 import Timestamp
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error

BATCH_JOB_NOT_FOUND_ERROR = "Batch Job Not Found"


class BatchJobManagerService(BatchJobManagementServiceServicer):
    def __init__(self):
        self.id_to_batch_job: Dict[str, MockBatchJob] = dict()
        self.model_id_active_warmup: Set[str] = set()
        self.models_to_fail: Set[str] = set()
        self.task_id_to_update_task_details: Dict[str, BatchTaskDetails] = dict()

    def StartBatchJob(
        self, request: StartBatchJobRequest, context
    ) -> StartBatchJobResponse:
        try:
            model_id = (
                request.model_id
                if request.model_id
                else request.batch_job_request.model_details.model_id
            )

            if model_id in self.models_to_fail:
                return StartBatchJobResponse(
                    success=False, failure_message="Model start failed"
                )
            mock_batch_job: MockBatchJob = MockBatchJob(request)
            self.id_to_batch_job[mock_batch_job.id] = mock_batch_job
            return StartBatchJobResponse(batch_id=mock_batch_job.id, success=True)
        except Exception as e:
            return StartBatchJobResponse(success=False, failure_message=str(e))

    def CancelBatchJob(
        self, request: CancelBatchJobRequest, context
    ) -> CancelBatchJobResponse:
        try:
            if request.batch_id in self.id_to_batch_job.keys():
                self.id_to_batch_job[
                    request.batch_id
                ].status = BatchJobStatusMessage.BATCH_JOB_CANCELLED_STATUS
                return CancelBatchJobResponse(success=True)
            else:
                return CancelBatchJobResponse(
                    success=False, failure_message=BATCH_JOB_NOT_FOUND_ERROR
                )
        except Exception as e:
            return CancelBatchJobResponse(success=False, failure_message=str(e))

    def StartWarmupJob(
        self, request: StartWarmupJobRequest, context
    ) -> StartWarmupJobResponse:
        try:
            self.model_id_active_warmup.add(request.model_id)
            return StartWarmupJobResponse(success=True)
        except Exception as e:
            return StartWarmupJobResponse(success=False, failure_message=str(e))

    def CancelWarmupJob(
        self, request: CancelWarmupJobRequest, context
    ) -> CancelWarmupJobResponse:
        try:
            if request.model_id in self.model_id_active_warmup:
                self.model_id_active_warmup.remove(request.model_id)
            return CancelWarmupJobResponse(success=True)
        except Exception as e:
            return CancelWarmupJobResponse(success=False, failure_message=str(e))

    def GetBatchJobStatus(
        self, request: GetBatchJobStatusRequest, context
    ) -> GetBatchJobStatusResponse:
        try:
            if request.batch_id in self.id_to_batch_job:
                batch_job = self.id_to_batch_job[request.batch_id]
                return GetBatchJobStatusResponse(
                    success=True,
                    job_status=batch_job.status,
                    finished_files=batch_job.finished_files,
                    total_files=batch_job.total_files,
                )
            else:
                return GetBatchJobStatusResponse(
                    success=False, failure_message=BATCH_JOB_NOT_FOUND_ERROR
                )
        except Exception as e:
            return GetBatchJobStatusResponse(success=False, failure_message=str(e))

    def GetBatchJobReport(
        self, request: GetBatchJobReportRequest, context
    ) -> GetBatchJobReportResponse:
        try:
            if request.batch_id in self.id_to_batch_job:
                batch_job = self.id_to_batch_job[request.batch_id]
                return GetBatchJobReportResponse(
                    successful=True, report_messages=batch_job.report
                )
            else:
                return GetBatchJobReportResponse(
                    successful=False, failure_message=BATCH_JOB_NOT_FOUND_ERROR
                )
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def ListBatchJobs(
        self, request: ListBatchJobsRequest, context
    ) -> ListBatchJobsResponse:
        try:
            if request.build_id:
                batch_jobs = list(
                    filter(
                        lambda job: job.start_request.build_id == request.build_id,
                        self.id_to_batch_job.values(),
                    )
                )
            else:
                batch_jobs = list(
                    filter(
                        lambda job: job.start_request.model_id == request.model_id,
                        self.id_to_batch_job.values(),
                    )
                )

            batch_jobs_details = list(map(batch_job_to_details, batch_jobs))
            return ListBatchJobsResponse(batch_jobs=batch_jobs_details)
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def GetBatchJobDetails(
        self, request: GetBatchJobDetailsRequest, context
    ) -> GetBatchJobDetailsResponse:
        try:
            if request.job_id in self.id_to_batch_job:
                return GetBatchJobDetailsResponse(
                    success=True,
                    batch_job=batch_job_to_message(
                        self.id_to_batch_job[request.job_id]
                    ),
                )
            else:
                return GetBatchJobDetailsResponse(
                    success=False, failure_message=BATCH_JOB_NOT_FOUND_ERROR
                )
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def GetBatchJobPreSignedUploadUrl(
        self, request: GetBatchJobPreSignedUploadUrlRequest, context
    ) -> GetBatchJobPreSignedUploadUrlResponse:
        try:
            return GetBatchJobPreSignedUploadUrlResponse(
                input_path="/input_path",
                output_path="/output_path",
                bucket="bucket",
                urls=[
                    f"{request.model_id}_{i}.{request.file_type}"
                    for i in range(request.number_of_files)
                ],
                success=True,
            )
        except Exception as e:
            return GetBatchJobPreSignedUploadUrlResponse(
                success=False, failure_message=str(e)
            )

    def GetBatchJobPreSignedDownloadUrl(
        self, request: GetBatchJobPreSignedDownloadUrlRequest, context
    ) -> GetBatchJobPreSignedDownloadUrlResponse:
        try:
            if request.job_id in self.id_to_batch_job:
                batch_job = self.id_to_batch_job[request.job_id]
                return GetBatchJobPreSignedDownloadUrlResponse(
                    urls=[
                        f"bucket://output_path/{batch_job.id}/{i}.{batch_job.start_request.output_file_type}"
                        for i in range(batch_job.total_files)
                    ],
                    success=True,
                )
            else:
                return GetBatchJobPreSignedDownloadUrlResponse(
                    success=False, failure_message=BATCH_JOB_NOT_FOUND_ERROR
                )
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def GetBatchJobUploadDetails(
        self, request: GetBatchJobUploadDetailsRequest, context
    ) -> GetBatchJobUploadDetailsResponse:
        try:
            return GetBatchJobUploadDetailsResponse(
                input_path="/input_path",
                output_path="/output_path",
                bucket="bucket",
                credentials=AwsTemporaryCredentials(
                    access_key_id="access_key_id",
                    secret_access_key="secret_access_key",
                    session_token="session_token",
                    expiration_time=Timestamp(seconds=3600),
                ),
            )
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def GetBatchJobDownloadDetails(
        self, request: GetBatchJobDownloadDetailsRequest, context
    ) -> GetBatchJobDownloadDetailsResponse:
        try:
            if request.job_id in self.id_to_batch_job:
                batch_job = self.id_to_batch_job[request.job_id]
                return GetBatchJobDownloadDetailsResponse(
                    bucket="bucket",
                    keys=[
                        f"bucket://output_path/{batch_job.id}/{i}.{batch_job.start_request.output_file_type}"
                        for i in range(batch_job.total_files)
                    ],
                    credentials=AwsTemporaryCredentials(
                        access_key_id="access_key_id",
                        secret_access_key="secret_access_key",
                        session_token="session_token",
                        expiration_time=Timestamp(seconds=3600),
                    ),
                )
            else:
                raise Exception(BATCH_JOB_NOT_FOUND_ERROR)
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def UpdateTasksDetails(
            self, request: UpdateTasksDetailsRequest, context
    ) -> UpdateTasksDetailsResponse:
        for task in request.tasks_details:
            task_id = task.task_id
            if not task_id :
                raise ValueError("Task ID cannot be empty")
            input_files = task.input_files_details

            print(f"Updating task with ID: {task_id} and input files: {[file.path for file in input_files]}")
            self.task_id_to_update_task_details[task_id] = task
        return UpdateTasksDetailsResponse()

    def get_task_details(self,task_id: str
        ) -> Optional[BatchTaskDetails]:
            """
            Get task details by task ID
            """
            return self.task_id_to_update_task_details[task_id]

class MockBatchJob:
    def __init__(self, request: StartBatchJobRequest):
        self.start_request: StartBatchJobRequest = request
        self.status: BatchJobStatusMessage = (
            BatchJobStatusMessage.BATCH_JOB_PENDING_STATUS
        )
        self.start_time: Timestamp = Timestamp()
        self.end_time: Optional[Timestamp] = None
        self.id: str = str(uuid.uuid4())
        self.finished_files: int = 0
        self.total_files: int = 0
        self.report: List[str] = []
        self.tasks: List[TaskExecutionDetails] = []

    def add_report_messages(self, messages: List[str]):
        self.report.extend(messages)

    def add_task_executions(self):
        self.tasks.append(
            TaskExecutionDetails(
                task_id=str(uuid.uuid4()),
                status=BatchTaskStatusMessage.BATCH_TASK_RUNNING_STATUS,
                start_time=Timestamp(),
                end_time=Timestamp(),
                filename="test",
            )
        )


def batch_job_to_details(batch_job: MockBatchJob) -> BatchJobDetails:
    return BatchJobDetails(
        build_id=batch_job.start_request.build_id,
        job_id=batch_job.id,
        job_status=batch_job.status,
        start_time=batch_job.start_time,
        end_time=batch_job.end_time,
        job_size=BatchJobDeploymentSize(
            number_of_pods=batch_job.start_request.batch_job_deployment_size.number_of_pods,
            cpu=batch_job.start_request.batch_job_deployment_size.cpu,
            memory_amount=batch_job.start_request.batch_job_deployment_size.memory_amount,
            memory_units=batch_job.start_request.batch_job_deployment_size.memory_units,
        ),
    )


def batch_job_to_message(batch_job: MockBatchJob) -> BatchJobMessage:
    return BatchJobMessage(
        job_id=batch_job.id,
        model_id=batch_job.start_request.model_id,
        branch_id=batch_job.start_request.branch_id,
        build_id=batch_job.start_request.build_id,
        start_time=batch_job.start_time,
        job_status=batch_job.status,
        end_time=batch_job.end_time,
        job_size=BatchJobDeploymentSize(
            number_of_pods=batch_job.start_request.batch_job_deployment_size.number_of_pods,
            cpu=batch_job.start_request.batch_job_deployment_size.cpu,
            memory_amount=batch_job.start_request.batch_job_deployment_size.memory_amount,
            memory_units=batch_job.start_request.batch_job_deployment_size.memory_units,
        ),
        report_messages=[
            ExecutionReportLine(time=Timestamp(), line=line)
            for line in batch_job.report
        ],
        task_executions=batch_job.tasks,
    )


"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.external.prometheus_config_pb2
import qwak.administration.runtime_configuration.v0.external.victoriametrics_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ObservabilityConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MONITORING_FIELD_NUMBER: builtins.int
    ALERTING_FIELD_NUMBER: builtins.int
    @property
    def monitoring(self) -> global___MonitoringConfiguration: ...
    @property
    def alerting(self) -> global___AlertingIntegrationConfiguration: ...
    def __init__(
        self,
        *,
        monitoring: global___MonitoringConfiguration | None = ...,
        alerting: global___AlertingIntegrationConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alerting", b"alerting", "monitoring", b"monitoring"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alerting", b"alerting", "monitoring", b"monitoring"]) -> None: ...

global___ObservabilityConfiguration = ObservabilityConfiguration

class MonitoringConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMETHEUS_FIELD_NUMBER: builtins.int
    VICTORIA_METRICS_FIELD_NUMBER: builtins.int
    @property
    def prometheus(self) -> qwak.administration.runtime_configuration.v0.external.prometheus_config_pb2.PrometheusConfiguration: ...
    @property
    def victoria_metrics(self) -> qwak.administration.runtime_configuration.v0.external.victoriametrics_config_pb2.VictoriaMetricsConfiguration: ...
    def __init__(
        self,
        *,
        prometheus: qwak.administration.runtime_configuration.v0.external.prometheus_config_pb2.PrometheusConfiguration | None = ...,
        victoria_metrics: qwak.administration.runtime_configuration.v0.external.victoriametrics_config_pb2.VictoriaMetricsConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["prometheus", b"prometheus", "type", b"type", "victoria_metrics", b"victoria_metrics"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prometheus", b"prometheus", "type", b"type", "victoria_metrics", b"victoria_metrics"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["prometheus", "victoria_metrics"] | None: ...

global___MonitoringConfiguration = MonitoringConfiguration

class AlertingIntegrationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMETHEUS_FIELD_NUMBER: builtins.int
    VICTORIA_METRICS_FIELD_NUMBER: builtins.int
    @property
    def prometheus(self) -> qwak.administration.runtime_configuration.v0.external.prometheus_config_pb2.PrometheusConfiguration: ...
    @property
    def victoria_metrics(self) -> qwak.administration.runtime_configuration.v0.external.victoriametrics_config_pb2.VictoriaMetricsConfiguration: ...
    def __init__(
        self,
        *,
        prometheus: qwak.administration.runtime_configuration.v0.external.prometheus_config_pb2.PrometheusConfiguration | None = ...,
        victoria_metrics: qwak.administration.runtime_configuration.v0.external.victoriametrics_config_pb2.VictoriaMetricsConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["prometheus", b"prometheus", "type", b"type", "victoria_metrics", b"victoria_metrics"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prometheus", b"prometheus", "type", b"type", "victoria_metrics", b"victoria_metrics"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["prometheus", "victoria_metrics"] | None: ...

global___AlertingIntegrationConfiguration = AlertingIntegrationConfiguration



from collections import defaultdict
from typing import Dict, List

from _qwak_proto.qwak.data_versioning.data_versioning_pb2 import DataTagSpec
from _qwak_proto.qwak.data_versioning.data_versioning_service_pb2 import (
    GetModelDataTagsRequest,
    GetModelDataTagsResponse,
    RegisterDataTagRequest,
    RegisterDataTagResponse,
)
from _qwak_proto.qwak.data_versioning.data_versioning_service_pb2_grpc import (
    DataVersioningManagementServiceServicer,
)
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error


class DataVersioningServiceMock(DataVersioningManagementServiceServicer):
    def __init__(self):
        super(DataVersioningServiceMock, self).__init__()
        self.tags: Dict[str : List[DataTagSpec]] = defaultdict(list)

    def RegisterDataTag(
        self, request: RegisterDataTagRequest, context
    ) -> RegisterDataTagResponse:
        try:
            self.tags[request.data_tag_spec.build_id].append(request.data_tag_spec)
            return RegisterDataTagResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def GetModelDataTags(
        self, request: GetModelDataTagsRequest, context
    ) -> GetModelDataTagsResponse:
        try:
            data_tags_list = []

            if not request.build_id:
                for all_data_tags in self.tags.values():
                    for data_tag in all_data_tags:
                        data_tags_list.append(data_tag)
            else:
                for data_tag_by_build_id in self.tags[request.build_id]:
                    if data_tag_by_build_id.model_id == request.model_id:
                        data_tags_list.append(data_tag_by_build_id)

            if request.filter:
                filter_type: str = request.filter.WhichOneof("filter")

                if filter_type == "tag_contains":
                    for data_tag in data_tags_list:
                        if request.filter.tag_contains not in data_tag.tag:
                            data_tags_list.remove(data_tag)

                if filter_type == "tag_prefix":
                    for data_tag in data_tags_list:
                        if not data_tag.tag.startswith(request.filter.tag_prefix):
                            data_tags_list.remove(data_tag)

            return GetModelDataTagsResponse(data_tags=data_tags_list)
        except Exception as e:
            raise_internal_grpc_error(context, e)



from typing import Optional

import grpc

from _qwak_proto.qwak.administration.v0.environments.environment_pb2 import (
    QwakEnvironment,
)
from _qwak_proto.qwak.administration.v0.environments.environment_service_pb2 import (
    CreateEnvironmentResponse,
    GetEnvironmentApplicationUserCredentialsResponse,
    GetEnvironmentResponse,
    ListEnvironmentsResponse,
    SetEnvironmentApplicationUserCredentialsResponse,
    UpdateEnvironmentConfigurationResponse,
    UpdateEnvironmentPersonalizationResponse,
)
from _qwak_proto.qwak.administration.v0.environments.environment_service_pb2_grpc import (
    EnvironmentServiceServicer,
)


class EnvironmentV0ServiceMock(EnvironmentServiceServicer):
    def __init__(self):
        super().__init__()
        self.__create_environment_response: Optional[CreateEnvironmentResponse] = None
        self.__create_environment_error: Optional[grpc.StatusCode] = None

        self.__get_environment_response: Optional[GetEnvironmentResponse] = None
        self.__get_environment_error: Optional[grpc.StatusCode] = None

        self.__update_environment_configuration_response: Optional[
            UpdateEnvironmentConfigurationResponse
        ] = None
        self.__update_environment_configuration_error: Optional[grpc.StatusCode] = None

        self.__update_environment_personalization_response: Optional[
            UpdateEnvironmentPersonalizationResponse
        ] = None
        self.__update_environment_personalization_error: Optional[grpc.StatusCode] = (
            None
        )

        self.__list_environments_response: Optional[ListEnvironmentsResponse] = None
        self.__list_environments_error: Optional[grpc.StatusCode] = None

        self.__get_credentials_response: Optional[
            GetEnvironmentApplicationUserCredentialsResponse
        ] = None
        self.__get_credentials_error: Optional[grpc.StatusCode] = None

        self.__set_credentials_response: Optional[
            SetEnvironmentApplicationUserCredentialsResponse
        ] = None
        self.__set_credentials_error: Optional[grpc.StatusCode] = None

    def given_create_environment(
        self,
        response: Optional[CreateEnvironmentResponse] = None,
        error_code: Optional[grpc.StatusCode] = None,
    ):
        self.__create_environment_response = response
        self.__create_environment_error = error_code

    def given_get_environment(
        self,
        response: Optional[GetEnvironmentResponse] = None,
        error_code: Optional[grpc.StatusCode] = None,
    ):
        self.__get_environment_response = response
        self.__get_environment_error = error_code

    def given_update_environment_configuration(
        self,
        response: Optional[UpdateEnvironmentConfigurationResponse] = None,
        error_code: Optional[grpc.StatusCode] = None,
    ):
        self.__update_environment_configuration_response = response
        self.__update_environment_configuration_error = error_code

    def given_update_environment_personalization(
        self,
        response: Optional[UpdateEnvironmentPersonalizationResponse] = None,
        error_code: Optional[grpc.StatusCode] = None,
    ):
        self.__update_environment_personalization_response = response
        self.__update_environment_personalization_error = error_code

    def given_list_environments(
        self,
        response: Optional[ListEnvironmentsResponse] = None,
        error_code: Optional[grpc.StatusCode] = None,
    ):
        self.__list_environments_response = response
        self.__list_environments_error = error_code

    def given_get_credentials(
        self,
        response: Optional[GetEnvironmentApplicationUserCredentialsResponse] = None,
        error_code: Optional[grpc.StatusCode] = None,
    ):
        self.__get_credentials_response = response
        self.__get_credentials_error = error_code

    def given_set_credentials(
        self,
        response: Optional[SetEnvironmentApplicationUserCredentialsResponse] = None,
        error_code: Optional[grpc.StatusCode] = None,
    ):
        self.__set_credentials_response = response
        self.__set_credentials_error = error_code

    def CreateEnvironment(self, request, context):
        if self.__create_environment_error:
            context.set_code(self.__create_environment_error)
            context.set_details("Failed to create environment")
            return CreateEnvironmentResponse()
        if self.__create_environment_response:
            return self.__create_environment_response
        return CreateEnvironmentResponse(environment=QwakEnvironment(id="mock-env-id"))

    def GetEnvironment(self, request, context):
        if self.__get_environment_error:
            context.set_code(self.__get_environment_error)
            context.set_details("Failed to get environment")
            return GetEnvironmentResponse()
        if self.__get_environment_response:
            return self.__get_environment_response
        return GetEnvironmentResponse(
            environment=QwakEnvironment(id=request.environment_id)
        )

    def UpdateEnvironmentConfiguration(self, request, context):
        if self.__update_environment_configuration_error:
            context.set_code(self.__update_environment_configuration_error)
            context.set_details("Failed to update environment configuration")
            return UpdateEnvironmentConfigurationResponse()
        if self.__update_environment_configuration_response:
            return self.__update_environment_configuration_response
        return UpdateEnvironmentConfigurationResponse()

    def UpdateEnvironmentPersonalization(self, request, context):
        if self.__update_environment_personalization_error:
            context.set_code(self.__update_environment_personalization_error)
            context.set_details("Failed to update environment personalization")
            return UpdateEnvironmentPersonalizationResponse()
        if self.__update_environment_personalization_response:
            return self.__update_environment_personalization_response
        return UpdateEnvironmentPersonalizationResponse()

    def ListEnvironments(self, request, context):
        if self.__list_environments_error:
            context.set_code(self.__list_environments_error)
            context.set_details("Failed to list environments")
            return ListEnvironmentsResponse()
        if self.__list_environments_response:
            return self.__list_environments_response
        return ListEnvironmentsResponse()

    def GetEnvironmentApplicationUserCredentials(self, request, context):
        if self.__get_credentials_error:
            context.set_code(self.__get_credentials_error)
            context.set_details("Failed to get credentials")
            return GetEnvironmentApplicationUserCredentialsResponse()
        if self.__get_credentials_response:
            return self.__get_credentials_response
        return GetEnvironmentApplicationUserCredentialsResponse()

    def SetEnvironmentApplicationUserCredentials(self, request, context):
        if self.__set_credentials_error:
            context.set_code(self.__set_credentials_error)
            context.set_details("Failed to set credentials")
            return SetEnvironmentApplicationUserCredentialsResponse()
        if self.__set_credentials_response:
            return self.__set_credentials_response
        return SetEnvironmentApplicationUserCredentialsResponse()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/features/aggregation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-qwak/feature_store/features/aggregation.proto\x12\'qwak.feature.store.features.aggregation\"\x85\t\n\x10\x41ggregationField\x12I\n\x0ctime_windows\x18\x01 \x03(\x0b\x32\x33.qwak.feature.store.features.aggregation.TimeWindow\x12\x19\n\x11\x66ield_name_prefix\x18\x02 \x01(\t\x12?\n\x05\x63ount\x18\x03 \x01(\x0b\x32..qwak.feature.store.features.aggregation.CountH\x00\x12;\n\x03sum\x18\x04 \x01(\x0b\x32,.qwak.feature.store.features.aggregation.SumH\x00\x12;\n\x03max\x18\x05 \x01(\x0b\x32,.qwak.feature.store.features.aggregation.MaxH\x00\x12;\n\x03min\x18\x06 \x01(\x0b\x32,.qwak.feature.store.features.aggregation.MinH\x00\x12;\n\x03\x61vg\x18\x07 \x01(\x0b\x32,.qwak.feature.store.features.aggregation.AvgH\x00\x12R\n\x0fsample_variance\x18\x08 \x01(\x0b\x32\x37.qwak.feature.store.features.aggregation.SampleVarianceH\x00\x12Z\n\x13population_variance\x18\t \x01(\x0b\x32;.qwak.feature.store.features.aggregation.PopulationVarianceH\x00\x12L\n\x0csample_stdev\x18\n \x01(\x0b\x32\x34.qwak.feature.store.features.aggregation.SampleSTDEVH\x00\x12T\n\x10population_stdev\x18\x0b \x01(\x0b\x32\x38.qwak.feature.store.features.aggregation.PopulationSTDEVH\x00\x12J\n\x0b\x62oolean_and\x18\x0c \x01(\x0b\x32\x33.qwak.feature.store.features.aggregation.BooleanAndH\x00\x12H\n\nboolean_or\x18\r \x01(\x0b\x32\x32.qwak.feature.store.features.aggregation.BooleanOrH\x00\x12Q\n\x0flast_distinct_n\x18\x0e \x01(\x0b\x32\x36.qwak.feature.store.features.aggregation.LastDistinctNH\x00\x12@\n\x06last_n\x18\x0f \x01(\x0b\x32..qwak.feature.store.features.aggregation.LastNH\x00\x12I\n\npercentile\x18\x10 \x01(\x0b\x32\x33.qwak.feature.store.features.aggregation.PercentileH\x00\x42\x0c\n\naggregator\"b\n\nTimeWindow\x12\x44\n\ttime_unit\x18\x01 \x01(\x0e\x32\x31.qwak.feature.store.features.aggregation.TimeUnit\x12\x0e\n\x06length\x18\x02 \x01(\x03\"\x1b\n\x05\x43ount\x12\x12\n\nfield_name\x18\x01 \x01(\t\"\x19\n\x03Sum\x12\x12\n\nfield_name\x18\x01 \x01(\t\"\x19\n\x03Max\x12\x12\n\nfield_name\x18\x01 \x01(\t\"\x19\n\x03Min\x12\x12\n\nfield_name\x18\x01 \x01(\t\"\x19\n\x03\x41vg\x12\x12\n\nfield_name\x18\x01 \x01(\t\"$\n\x0eSampleVariance\x12\x12\n\nfield_name\x18\x01 \x01(\t\"(\n\x12PopulationVariance\x12\x12\n\nfield_name\x18\x01 \x01(\t\"!\n\x0bSampleSTDEV\x12\x12\n\nfield_name\x18\x01 \x01(\t\"%\n\x0fPopulationSTDEV\x12\x12\n\nfield_name\x18\x01 \x01(\t\" \n\nBooleanAnd\x12\x12\n\nfield_name\x18\x01 \x01(\t\"\x1f\n\tBooleanOr\x12\x12\n\nfield_name\x18\x01 \x01(\t\".\n\rLastDistinctN\x12\x12\n\nfield_name\x18\x01 \x01(\t\x12\t\n\x01n\x18\x02 \x01(\x05\"&\n\x05LastN\x12\x12\n\nfield_name\x18\x01 \x01(\t\x12\t\n\x01n\x18\x02 \x01(\x05\"+\n\nPercentile\x12\x12\n\nfield_name\x18\x01 \x01(\t\x12\t\n\x01p\x18\x02 \x01(\x05*\x8d\x01\n\x08TimeUnit\x12\x15\n\x11TIME_UNIT_INVALID\x10\x00\x12\x13\n\x0fTIME_UNIT_WEEKS\x10\x03\x12\x12\n\x0eTIME_UNIT_DAYS\x10\x04\x12\x13\n\x0fTIME_UNIT_HOURS\x10\x05\x12\x15\n\x11TIME_UNIT_MINUTES\x10\x06\x12\x15\n\x11TIME_UNIT_SECONDS\x10\x07\x42^\n)com.qwak.ai.feature.store.aggregation.apiP\x01Z/qwak/featurestore/features;featurestorefeaturesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.features.aggregation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.feature.store.aggregation.apiP\001Z/qwak/featurestore/features;featurestorefeatures'
  _globals['_TIMEUNIT']._serialized_start=1842
  _globals['_TIMEUNIT']._serialized_end=1983
  _globals['_AGGREGATIONFIELD']._serialized_start=91
  _globals['_AGGREGATIONFIELD']._serialized_end=1248
  _globals['_TIMEWINDOW']._serialized_start=1250
  _globals['_TIMEWINDOW']._serialized_end=1348
  _globals['_COUNT']._serialized_start=1350
  _globals['_COUNT']._serialized_end=1377
  _globals['_SUM']._serialized_start=1379
  _globals['_SUM']._serialized_end=1404
  _globals['_MAX']._serialized_start=1406
  _globals['_MAX']._serialized_end=1431
  _globals['_MIN']._serialized_start=1433
  _globals['_MIN']._serialized_end=1458
  _globals['_AVG']._serialized_start=1460
  _globals['_AVG']._serialized_end=1485
  _globals['_SAMPLEVARIANCE']._serialized_start=1487
  _globals['_SAMPLEVARIANCE']._serialized_end=1523
  _globals['_POPULATIONVARIANCE']._serialized_start=1525
  _globals['_POPULATIONVARIANCE']._serialized_end=1565
  _globals['_SAMPLESTDEV']._serialized_start=1567
  _globals['_SAMPLESTDEV']._serialized_end=1600
  _globals['_POPULATIONSTDEV']._serialized_start=1602
  _globals['_POPULATIONSTDEV']._serialized_end=1639
  _globals['_BOOLEANAND']._serialized_start=1641
  _globals['_BOOLEANAND']._serialized_end=1673
  _globals['_BOOLEANOR']._serialized_start=1675
  _globals['_BOOLEANOR']._serialized_end=1706
  _globals['_LASTDISTINCTN']._serialized_start=1708
  _globals['_LASTDISTINCTN']._serialized_end=1754
  _globals['_LASTN']._serialized_start=1756
  _globals['_LASTN']._serialized_end=1794
  _globals['_PERCENTILE']._serialized_start=1796
  _globals['_PERCENTILE']._serialized_end=1839
# @@protoc_insertion_point(module_scope)



from typing import Optional


class LoginArguments(object):
    isAnonymous: bool = False
    server_id: Optional[str] = None
    username: Optional[str] = None
    password: Optional[str] = None
    access_token: Optional[str] = None
    artifactory_url: Optional[str] = None

    def __eq__(self, other):
        if not isinstance(other, LoginArguments):
            return False
        return (
            self.isAnonymous == other.isAnonymous
            and self.server_id == other.server_id
            and self.username == other.username
            and self.password == other.password
            and self.access_token == other.access_token
            and self.artifactory_url == other.artifactory_url
        )



from datetime import timedelta
from typing import Optional
import requests
from requests import Response

from _qwak_proto.qwak.builds.build_url_pb2 import BuildVersioningTagsType
from _qwak_proto.qwak.builds.builds_orchestrator_service_pb2 import (
    GetBuildVersioningUploadURLResponse,
    GetBuildVersioningDownloadURLResponse,
)
from qwak.clients.build_orchestrator.client import BuildOrchestratorClient
from qwak.clients.file_versioning.client import FileVersioningManagementClient
from qwak.exceptions import QwakException
from qwak.inner.model_loggers_utils import (
    fetch_build_id,
    upload_data,
    validate_model,
    validate_tag,
)

MAX_CHUNK_SIZE = 8 * 1024


def log_file(
    from_path: str,
    tag: str = "artifact",
    model_id: Optional[str] = None,
    build_id: Optional[str] = None,
) -> None:
    """
    Log a file by a given tag

    Args:
        from_path: file path to log
        tag: tag to save the file with
        model_id: optional model id to save data with - if not given found from environment
        build_id: optional build id - if not given found from environment.
    """
    if not validate_tag(tag):
        raise QwakException(
            "Tag should contain only letters, numbers, underscore or hyphen"
        )

    model_id = validate_model(model_id)
    if not build_id:
        # Checking if called inside a model - then build id saved as environment variable or stays
        build_id = fetch_build_id()

    upload_url_response: (
        GetBuildVersioningUploadURLResponse
    ) = BuildOrchestratorClient().get_build_versioning_upload_url(
        build_id=build_id,
        model_id=model_id,
        tag=tag,
        tag_type=BuildVersioningTagsType.FILE_TAG_TYPE,
    )

    FileVersioningManagementClient().register_file_tag(
        model_id, tag, from_path, build_id
    )

    with open(from_path, mode="rb") as f:
        upload_data(
            upload_url_response.upload_url,
            f.read(),
            upload_url_response.headers,
        )


def load_file(
    to_path: str,
    tag: str = "artifact",
    model_id: Optional[str] = None,
    build_id: Optional[str] = None,
) -> str:
    """
    Load a file by a given tag

    Args:
        to_path: the local path the downloaded file will be written to
        tag: load the artifact with this given tag
        model_id: optional model id to save data with - if not given found from environment
        build_id: optional build id - if not given found from environment.

    Returns:
        the path to the newly created data file
    """
    print(f"Loading file to {to_path}")
    if not validate_tag(tag):
        raise QwakException(
            "Tag should contain only letters, numbers, underscore or hyphen"
        )

    model_id = validate_model(model_id)
    download_url_response: (
        GetBuildVersioningDownloadURLResponse
    ) = BuildOrchestratorClient().get_build_versioning_download_url(
        build_id=build_id,
        model_id=model_id,
        tag=tag,
        tag_type=BuildVersioningTagsType.FILE_TAG_TYPE,
    )

    try:
        response: Response = requests.get(
            download_url_response.download_url,
            headers=download_url_response.headers,
            stream=True,
            timeout=(
                timedelta(seconds=10).total_seconds(),  # timeout to connect
                timedelta(minutes=20).total_seconds(),  # timeout to read
            ),
        )
        print(f"Downloading file finished with status {response.status_code}")
        response.raise_for_status()

        with open(to_path, "wb") as f:
            for chunk in response.iter_content(chunk_size=MAX_CHUNK_SIZE):
                if chunk:
                    f.write(chunk)

        return to_path
    except Exception as error:
        raise QwakException(f"Unable to load save artifact locally: {str(error)}")



from typing import List, Optional, Union

import typer

from frogml_storage.utils import assemble_artifact_url, join_url
from frogml_storage.authentication.login._login_command import run as run_login
from frogml_storage.authentication.models import AuthConfig, LoginArguments
from frogml_storage.authentication.utils import (
    get_frogml_configuration,
    parse_cli_config_server,
    read_jfrog_cli_config,
)
from frogml_storage.authentication.utils import (
    get_list_of_servers_from_config,
    login_input_checks,
    is_login_without_params,
)
from frogml_storage.constants import CONFIG_FILE_PATH, JFROG_CLI_CONFIG_FILE_PATH


def login(
    url: Optional[str],
    username: Optional[str],
    password: Optional[str],
    token: Optional[str],
    anonymous: Optional[bool],
    is_interactive: Optional[bool],
) -> bool:
    if anonymous is None:
        anonymous = False
    if is_login_without_params(url, username, password, token, anonymous):
        if not is_interactive:
            return __login_by_frogml_configuration_file_flow()
        else:
            return __interactive_flow()
    elif login_input_checks(url, username, password, token, anonymous):
        url = assemble_artifact_url(url)
        return __login_by_command_line_params(url, username, password, token, anonymous)
    else:
        typer.echo(
            f"{__get_failed_reason(url, username, password, token, anonymous)}Login failed"
        )
        return False


def __get_failed_reason(
    url: Optional[str],
    username: Optional[str],
    password: Optional[str],
    token: Optional[str],
    anonymous: Optional[bool],
) -> str:
    details = ""
    if url is None:
        details += "Url is required.\n"
    if token is not None and (
        any(params is not None for params in [username, password])
    ):
        details += "Token cannot be used together with username/password.\n"
    if anonymous is True and any(
        params is not None for params in [username, password, token]
    ):
        details += "Anonymous is specified with authentication details.\n"
    if username is None and password is not None:
        details += "Username is required when password is specified.\n"
    elif username is not None and password is None:
        details += "Password is required when username is specified.\n"
    return details


def __run_interactive_mode() -> Union[LoginArguments, None]:
    jfrog_cli_config = read_jfrog_cli_config()

    if jfrog_cli_config is not None:
        jfrog_cli_servers = get_list_of_servers_from_config(jfrog_cli_config)
        if jfrog_cli_servers is not None and len(jfrog_cli_servers) > 0:
            login_method_id = typer.prompt(
                f"Please select from the following options:\n"  # nosec B608
                f"1.Login by jfrog-cli configuration file: {JFROG_CLI_CONFIG_FILE_PATH}\n"
                f"2.Connecting to a new server\n"
            )

            while (
                not login_method_id.isdigit()
                or int(login_method_id) > 2
                or int(login_method_id) <= 0
            ):
                login_method_id = typer.prompt(
                    "Bad Input. Choose your preferred login option"
                )

            login_method_id = int(login_method_id)
            if login_method_id == 1:
                return __prompt_jfrog_cli_configuration_list(
                    jfrog_cli_config, jfrog_cli_servers
                )

        return __prompt_manual_details()

    return None


def __prompt_manual_details() -> Union[LoginArguments, None]:
    login_args = LoginArguments()
    login_args.artifactory_url = typer.prompt("Enter artifactory base url")

    if login_args.artifactory_url is not None:
        login_args.artifactory_url = join_url(login_args.artifactory_url, "artifactory")

    auth_options = ["Username and Password", "Access Token", "Anonymous Access"]
    authentication_types = ""
    for index, item in enumerate(auth_options):
        authentication_types += f"{index}: {item} \n"
    selected_auth_type = typer.prompt(
        f"Choose your preferred authentication option:\n{authentication_types}"
    )
    while (
        not selected_auth_type.isdigit()
        or int(selected_auth_type) >= len(auth_options)
        or int(selected_auth_type) < 0
    ):
        selected_auth_type = typer.prompt(
            "Bad Input. Choose your preferred authentication"
        )
    selected_auth_type = int(selected_auth_type)
    if selected_auth_type == 0:
        return __prompt_username_password(login_args)
    elif selected_auth_type == 1:
        return __prompt_access_token(login_args)
    elif selected_auth_type == 2:
        login_args.isAnonymous = True
        return login_args
    return None


def __prompt_username_password(login_args: LoginArguments) -> LoginArguments:
    username = typer.prompt("Enter JFrog user name")
    password = typer.prompt("Enter JFrog password", hide_input=True)
    login_args.username = username
    login_args.password = password
    return login_args


def __prompt_access_token(login_args: LoginArguments) -> LoginArguments:
    token = typer.prompt("Enter JFrog access token", hide_input=True)
    login_args.access_token = token
    return login_args


def __prompt_jfrog_cli_configuration_list(
    jfrog_cli_config: dict, jfrog_cli_servers: List[str]
) -> Union[LoginArguments, None]:
    list_server_options = ""
    for index, item in enumerate(jfrog_cli_servers):
        list_server_options += f"{index}: {item}\n"
    server_index_cli_conf = typer.prompt(
        f"Found the following servers in your JFrog CLI configuration, "
        f"choose one of the following:\n{list_server_options}"
    )
    while (
        not server_index_cli_conf.isdigit()
        or int(server_index_cli_conf) < 0
        or int(server_index_cli_conf) >= len(jfrog_cli_servers)
    ):
        server_index_cli_conf = typer.prompt(
            "Invalid choice. Please choose a number from the list"
        )
    server_index_cli_conf = int(server_index_cli_conf)
    typer.echo(f"{jfrog_cli_servers[server_index_cli_conf]} was chosen")
    servers = jfrog_cli_config.get("servers")
    if servers is not None:
        return parse_cli_config_server(servers[server_index_cli_conf])
    else:
        raise ValueError("No servers found in the JFrog CLI configuration.")


def __execute_login(auth_config: AuthConfig, anonymous: bool) -> bool:
    if run_login(auth_config, anonymous):
        success_message = "Logged in successfully"
        if auth_config.artifactory_url is not None:
            success_message += (
                f" to: {auth_config.artifactory_url.replace('/artifactory', '')}"
            )
        typer.echo(success_message)
        return True
    else:
        typer.echo("Failed to login, bad authentication")
        return False


def __login_by_frogml_configuration_file_flow() -> bool:
    login_args = get_frogml_configuration()
    auth_config = None
    if login_args is not None:
        typer.echo(
            f"Using existing frogml authentication config file: {CONFIG_FILE_PATH}"
        )
        auth_config = AuthConfig(
            artifactory_url=login_args.artifactory_url,
            user=login_args.username,
            password=login_args.password,
            access_token=login_args.access_token,
        )

    if (
        auth_config is not None
        and login_args is not None
        and __execute_login(auth_config, login_args.isAnonymous)
    ):
        return True

    return __interactive_flow()


def __interactive_flow() -> bool:
    login_args = __run_interactive_mode()
    if login_args is not None:
        auth_config = AuthConfig(
            artifactory_url=login_args.artifactory_url,
            user=login_args.username,
            password=login_args.password,
            access_token=login_args.access_token,
        )
        return __execute_login(auth_config, login_args.isAnonymous)
    return False


def __login_by_command_line_params(
    url: str,
    username: Optional[str],
    password: Optional[str],
    token: Optional[str],
    anonymous: Optional[bool],
) -> bool:
    anonymous_value = anonymous if anonymous is not None else False
    auth_config = AuthConfig(
        artifactory_url=url, user=username, password=password, access_token=token
    )
    return __execute_login(auth_config, anonymous_value)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.analytics.analytics_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    query: builtins.str
    """The query string"""
    def __init__(
        self,
        *,
        query: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query", b"query"]) -> None: ...

global___QueryRequest = QueryRequest

class QueryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_ID_FIELD_NUMBER: builtins.int
    query_id: builtins.str
    """The query ID to get result for"""
    def __init__(
        self,
        *,
        query_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query_id", b"query_id"]) -> None: ...

global___QueryResponse = QueryResponse

class ExecuteDdlQueryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    query: builtins.str
    """The query string"""
    def __init__(
        self,
        *,
        query: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query", b"query"]) -> None: ...

global___ExecuteDdlQueryRequest = ExecuteDdlQueryRequest

class ExecuteDdlQueryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_ID_FIELD_NUMBER: builtins.int
    query_id: builtins.str
    """The query ID to get result for"""
    def __init__(
        self,
        *,
        query_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query_id", b"query_id"]) -> None: ...

global___ExecuteDdlQueryResponse = ExecuteDdlQueryResponse

class GetQueryResultsPageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_ID_FIELD_NUMBER: builtins.int
    PAGE_ID_FIELD_NUMBER: builtins.int
    MAX_RESULTS_FIELD_NUMBER: builtins.int
    query_id: builtins.str
    """The query ID to get result for"""
    page_id: builtins.str
    """ID of the next page"""
    max_results: builtins.int
    """Max results per response (per page)"""
    def __init__(
        self,
        *,
        query_id: builtins.str = ...,
        page_id: builtins.str = ...,
        max_results: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_results", b"max_results", "page_id", b"page_id", "query_id", b"query_id"]) -> None: ...

global___GetQueryResultsPageRequest = GetQueryResultsPageRequest

class GetQueryResultsPageResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    NEXT_PAGE_ID_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    status: qwak.analytics.analytics_pb2.QueryStatus.ValueType
    """The query status"""
    failure_reason: builtins.str
    """Failure message if failed"""
    next_page_id: builtins.str
    """The ID of the next page"""
    @property
    def data(self) -> qwak.analytics.analytics_pb2.ResultData:
        """The result set"""
    def __init__(
        self,
        *,
        status: qwak.analytics.analytics_pb2.QueryStatus.ValueType = ...,
        failure_reason: builtins.str = ...,
        next_page_id: builtins.str = ...,
        data: qwak.analytics.analytics_pb2.ResultData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "failure_reason", b"failure_reason", "next_page_id", b"next_page_id", "status", b"status"]) -> None: ...

global___GetQueryResultsPageResponse = GetQueryResultsPageResponse

class GetQueryStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_ID_FIELD_NUMBER: builtins.int
    query_id: builtins.str
    """The query ID to get result for"""
    def __init__(
        self,
        *,
        query_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query_id", b"query_id"]) -> None: ...

global___GetQueryStatusRequest = GetQueryStatusRequest

class GetQueryStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    status: qwak.analytics.analytics_pb2.QueryStatus.ValueType
    """The query status"""
    failure_reason: builtins.str
    """Failure message if failed"""
    def __init__(
        self,
        *,
        status: qwak.analytics.analytics_pb2.QueryStatus.ValueType = ...,
        failure_reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_reason", b"failure_reason", "status", b"status"]) -> None: ...

global___GetQueryStatusResponse = GetQueryStatusResponse

class DescribeTableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_NAME_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    table_name: builtins.str
    """The table to describe"""
    database_name: builtins.str
    """The database to describe"""
    def __init__(
        self,
        *,
        table_name: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_name", b"database_name", "table_name", b"table_name"]) -> None: ...

global___DescribeTableRequest = DescribeTableRequest

class DescribeTableResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_NAME_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    table_name: builtins.str
    """The name of the described table"""
    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.analytics.analytics_pb2.TableColumn]:
        """List of table columns"""
    def __init__(
        self,
        *,
        table_name: builtins.str = ...,
        columns: collections.abc.Iterable[qwak.analytics.analytics_pb2.TableColumn] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["columns", b"columns", "table_name", b"table_name"]) -> None: ...

global___DescribeTableResponse = DescribeTableResponse

class ListTableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListTableRequest = ListTableRequest

class ListTableResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_NAMES_FIELD_NUMBER: builtins.int
    @property
    def table_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of tables"""
    def __init__(
        self,
        *,
        table_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["table_names", b"table_names"]) -> None: ...

global___ListTableResponse = ListTableResponse

class CreateTableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_FIELD_NUMBER: builtins.int
    @property
    def table(self) -> qwak.analytics.analytics_pb2.TableDefinition: ...
    def __init__(
        self,
        *,
        table: qwak.analytics.analytics_pb2.TableDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["table", b"table"]) -> None: ...

global___CreateTableRequest = CreateTableRequest

class CreateTableResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreateTableResponse = CreateTableResponse

class GetQueryResultDownloadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> qwak.analytics.analytics_pb2.QueryResultDownloadURLParams:
        """The params to define the query result"""
    def __init__(
        self,
        *,
        params: qwak.analytics.analytics_pb2.QueryResultDownloadURLParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___GetQueryResultDownloadURLRequest = GetQueryResultDownloadURLRequest

class GetQueryResultDownloadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    download_url: builtins.str
    """Download url - to download the wanted artifact"""
    def __init__(
        self,
        *,
        download_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["download_url", b"download_url"]) -> None: ...

global___GetQueryResultDownloadURLResponse = GetQueryResultDownloadURLResponse

class OptimizeTableRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    table_name: builtins.str
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        table_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "table_name", b"table_name"]) -> None: ...

global___OptimizeTableRequest = OptimizeTableRequest

class OptimizeTableResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_ID_FIELD_NUMBER: builtins.int
    query_id: builtins.str
    def __init__(
        self,
        *,
        query_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query_id", b"query_id"]) -> None: ...

global___OptimizeTableResponse = OptimizeTableResponse

class CreateDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_NAME_FIELD_NUMBER: builtins.int
    database_name: builtins.str
    def __init__(
        self,
        *,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_name", b"database_name"]) -> None: ...

global___CreateDatabaseRequest = CreateDatabaseRequest

class CreateDatabaseResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreateDatabaseResponse = CreateDatabaseResponse



from frogml_storage.models.frogml_entity_version import FrogMLEntityVersion


class FrogMLDatasetVersion(FrogMLEntityVersion):
    """
    Represent metadata of an uploaded dataset version.

    Inherits:
        FrogMLEntityVersion: Base class for entity versions.
    """

    @classmethod
    def from_entity_version(
        cls, entity_version: FrogMLEntityVersion
    ) -> "FrogMLDatasetVersion":
        return cls(
            entity_name=entity_version.entity_name,
            version=entity_version.version,
            namespace=entity_version.namespace,
            entity_manifest=entity_version.entity_manifest,
        )
